; Talking Voltmeter
;
; K Orton 2007

; PIC constants
W	EQU	0
F	EQU	1
PCL	EQU	H'0002'
STATUS	EQU	H'0003'
PORTA	EQU	H'0005'
PORTB	EQU	H'0006'
PORTC	EQU	H'0007'
INTCON	EQU	H'000B'
PIR1	EQU	H'000C'
T2CON	EQU	H'0012'
CCPR1L	EQU	H'0015'
CCP1CN	EQU	H'0017'
ADRESH	EQU	H'001E'
ADCON0	EQU	H'001F'
OPTREG	EQU	H'0081'
TRISA	EQU	H'0085'
TRISB	EQU	H'0086'
TRISC	EQU	H'0087'
PR2	EQU	H'0092'
ADRESL	EQU	H'009E'
ADCON1	EQU	H'009F'
EEDATA	EQU	H'010C'
EEADR	EQU	H'010D'
EEDATH	EQU	H'010E'
EEADRH	EQU	H'010F'
EECON1	EQU	H'018C'
TMR2IF	EQU	1
GODONE	EQU	2
RD	EQU	0
PGD	EQU	7
C	EQU	0
Z	EQU	2
RP0	EQU	5
RP1	EQU	6
CFG	EQU	H'393A'

	__CONFIG	CFG

; Program constants
ADRHI	EQU	H'0070'
ADRLO	EQU	H'0071'
CNTHI	EQU	H'0072'
CNTLO	EQU	H'0073'
SILHI	EQU	H'0074'
SILLO	EQU	H'0075'
SMPHI	EQU	H'0076'
SMPLO	EQU	H'0077'
DEN	EQU	H'0078'
DIG0	EQU	H'0079'
DIG1	EQU	H'007A'
DIG2	EQU	H'007B'
DIG3	EQU	H'007C'
TMP	EQU	H'007D'
DUR	EQU	D'1470'		; Play duration = 0.4sec

; Play sample macro
PLAYM	MACRO	BASE,LEN
	MOVLW	HIGH(BASE)
	MOVWF	ADRHI
	MOVLW	LOW(BASE)
	MOVWF	ADRLO
	MOVLW	HIGH(LEN)
	MOVWF	CNTHI
	MOVLW	LOW(LEN)
	MOVWF	CNTLO
	GOTO	PLAY
	ENDM

; PIC reset
	ORG	0
	CLRF	INTCON			; No interrupts
	BSF	STATUS,RP0		; Set options:
	MOVLW	B'11010111'		;  No RB pull-ups
	MOVWF	OPTREG
	MOVLW	B'00000001'		; Set up digital I/O:
	MOVWF	TRISA			;  RA0 is analogue input
	CLRF	TRISB			;  RC2 is PWM output
	CLRF	TRISC			;  All other I/O pins are
	BCF	STATUS,RP0		;  outputs asserted low
	CLRF	PORTA
	CLRF	PORTB
	CLRF	PORTC
	BSF	STATUS,RP0		; Set up ADC:
	MOVLW	B'10001110'		;  Right justified data
	MOVWF	ADCON1			;  RA0 only and supply ref
	BCF	STATUS,RP0
	MOVLW	B'10000000'		;  Select RA0 and Fosc/32
	MOVWF	ADCON0
	MOVLW	B'10000001'		;  Enable ADC
	MOVWF	ADCON0
	BSF	STATUS,RP0		; Set up CCP1:
	MOVLW	D'135'			;  PWM frequency = 36.76kHz
	MOVWF	PR2
	BCF	STATUS,RP0
	MOVLW	D'64'			;  Output mid code for now
	MOVWF	CCPR1L
	CLRF	CCP1CN
	CLRF	T2CON			;  Timer 2 1:1 in and out
	MOVLW	B'00000100'		;  Enable timer 2
	MOVWF	T2CON
	MOVLW	B'00001100'		;  Set CCP1 to PWM mode
	MOVWF	CCP1CN

; Main loop
LOOP	CALL	ADCONV			; Get a measurement
	MOVLW	D'10'			; Get digits
	MOVWF	DEN
	CALL	DIV
	MOVF	CNTLO,W
	MOVWF	DIG0
	CALL	DIV
	MOVF	CNTLO,W
	MOVWF	DIG1
	CALL	DIV
	MOVF	CNTLO,W
	MOVWF	DIG2
	MOVF	SMPLO,W
	MOVWF	DIG3
	MOVF	DIG3,W			; Speak it!
	CALL	PLAYD
	CALL	PLAYP
	MOVF	DIG2,W
	CALL	PLAYD
	MOVF	DIG1,W
	CALL	PLAYD
	CALL	PAUSE
	GOTO	LOOP

; Do ADC conversion
; Sample (in millivolts) returned in SMPHI, SMPLO
; Uses CNTLO and TMP
ADCONV	CLRF	SMPHI			; Sum up 44 samples
	CLRF	SMPLO
	MOVLW	D'44'
	MOVWF	CNTLO
ADCLP1	MOVLW	D'41'			; Allow 25usec acquisition
	MOVWF	TMP
ADCLP2	DECFSZ	TMP,F
	GOTO	ADCLP2
	BSF	ADCON0,GODONE		; Do a conversion
ADCLP3	BTFSC	ADCON0,GODONE
	GOTO	ADCLP3
	MOVF	ADRESH,W		; Add sample to sum
	ADDWF	SMPHI,F
	BSF	STATUS,RP0
	MOVF	ADRESL,W
	BCF	STATUS,RP0
	ADDWF	SMPLO,F
	BTFSC	STATUS,C
	INCF	SMPHI,F
	DECFSZ	CNTLO,F
	GOTO	ADCLP1
	MOVLW	9			; Divide sum by 9. This
	MOVWF	DEN			;  leaves millivolts in
;	GOTO	DIV			;  SMPHI, SMPLO

; Divide measurement by DEN
; Remainder returned in CNTLO
; Uses CNTHI, CNTLO
DIV	MOVF	SMPHI,W		; Move SMP->CNT
	MOVWF	CNTHI
	MOVF	SMPLO,W
	MOVWF	CNTLO
	CLRF	SMPHI			; Zero quotient
	CLRF	SMPLO
	MOVF	DEN,W			; Get denominator
DIVLP1	SUBWF	CNTHI,F		; Divide high byte
	INCF	SMPHI,F
	BTFSC	STATUS,C
	GOTO	DIVLP1
	ADDWF	CNTHI,F		; Overstepped!
	DECF	SMPHI,F
DIVLP2	SUBWF	CNTLO,F		; Divide low byte
	INCF	SMPLO,F
	BTFSC	STATUS,C
	GOTO	DIVLP2
	MOVF	CNTHI,F
	BTFSC	STATUS,Z
	GOTO	DIVEND
	DECF	CNTHI,F
	GOTO	DIVLP2
DIVEND	ADDWF	CNTLO,F
	DECF	SMPLO,F
	RETURN

; Play a digit
; Digit 0..9 expected in W
PLAYD	ADDWF	PCL,F
	GOTO	PLAY0
	GOTO	PLAY1
	GOTO	PLAY2
	GOTO	PLAY3
	GOTO	PLAY4
	GOTO	PLAY5
	GOTO	PLAY6
	GOTO	PLAY7
	GOTO	PLAY8
	GOTO	PLAY9

; Play sampled sound functions
PLAY0	PLAYM	SMP0,SMP1-SMP0
PLAY1	PLAYM	SMP1,SMP2-SMP1
PLAY2	PLAYM	SMP2,SMP3-SMP2
PLAY3	PLAYM	SMP3,SMP4-SMP3
PLAY4	PLAYM	SMP4,SMP5-SMP4
PLAY5	PLAYM	SMP5,SMP6-SMP5
PLAY6	PLAYM	SMP6,SMP7-SMP6
PLAY7	PLAYM	SMP7,SMP8-SMP7
PLAY8	PLAYM	SMP8,SMP9-SMP8
PLAY9	PLAYM	SMP9,SMPP-SMP9
PLAYP	PLAYM	SMPP,SMPEND-SMPP

; Play a pause between readings
PAUSE	MOVLW	HIGH DUR
	MOVWF	SILHI
	MOVLW	LOW DUR
	MOVWF	SILLO
	GOTO	SIL

; Play sample
; Sample address expected in ADRHI, ADRLO (left advanced by CNT)
; Sample length expected in CNTHI, CNTLO (zeroed)
; Sample is padded out to DUR samples with silence
; Uses SILHI, SILLO and TMP
PLAY	MOVLW	HIGH DUR		; Get silence required
	MOVWF	SILHI
	MOVLW	LOW DUR
	MOVWF	SILLO
	MOVF	CNTHI,W
	SUBWF	SILHI,F
	MOVF	CNTLO,W
	SUBWF	SILLO,F
	BTFSS	STATUS,C
	DECF	SILHI,F
	CALL	SYNPWM			; Re-synchronise to PWM
PLAYLP	BSF	STATUS,RP1		; Read sample pair from
	MOVF	ADRLO,W		;  program memory
	MOVWF	EEADR
	MOVF	ADRHI,W
	MOVWF	EEADRH
	BSF	STATUS,RP0
	BSF	EECON1,PGD
	BSF	EECON1,RD
	NOP
	NOP
	BCF	STATUS,RP0
	MOVF	EEDATA,W
	MOVWF	SMPLO
	MOVF	EEDATH,W
	MOVWF	SMPHI
	BCF	STATUS,RP1
	INCF	ADRHI,F		; Advance address
	INCFSZ	ADRLO,F
	DECF	ADRHI,F
	RLF	SMPLO,W		; Put first sample to
	RLF	SMPHI,W		;  PWM
	MOVWF	CCPR1L
	MOVLW	5			; Five PWM cycles per
	MOVWF	TMP			;  sample
WTLP1	CALL	SYNPWM
	DECFSZ	TMP,F
	GOTO	WTLP1
	MOVF	SMPLO,W		; Put second sample to
	ANDLW	B'01111111'		;  PWM
	MOVWF	CCPR1L
	MOVLW	5
	MOVWF	TMP
WTLP2	CALL	SYNPWM
	DECFSZ	TMP,F
	GOTO	WTLP2
	MOVF	CNTLO,F		; Decrement count
	BTFSC	STATUS,Z
	DECF	CNTHI,F
	DECF	CNTLO,F
	MOVF	CNTLO,W
	IORWF	CNTHI,W
	BTFSS	STATUS,Z
	GOTO	PLAYLP			; Loop back if not done
	MOVLW	D'64'			; Return to silence
	MOVWF	CCPR1L
;	GOTO	SIL

; Play silence
; Silence length expected in SILHI, SILLO (left zeroed)
; Uses TMP
SIL	MOVLW	D'10'			; Skip two samples'
	MOVWF	TMP			;  PWM periods
SILLP	CALL	SYNPWM
	DECFSZ	TMP,F
	GOTO	SILLP
	MOVF	SILLO,F
	BTFSC	STATUS,Z
	DECF	SILHI,F
	DECF	SILLO,F
	MOVF	SILLO,W
	IORWF	SILHI,W
	BTFSS	STATUS,Z
	GOTO	SIL
	RETURN

; Synchronise to PWM
SYNPWM	BCF	PIR1,TMR2IF
SYNLP	BTFSS	PIR1,TMR2IF
	GOTO	SYNLP
	RETURN
	
; Digit samples
SMP0	DW	0x2142, 0x21C3, 0x2141, 0x2041, 0x20C3, 0x21C3, 0x2142, 0x2144, 0x22C4, 0x21C5, 0x23C8, 0x2345, 0x2243, 0x20C0, 0x2041, 0x21C3
	DW	0x203E, 0x2044, 0x213C, 0x1FC2, 0x2245, 0x2245, 0x2448, 0x254D, 0x274C, 0x23C2, 0x203E, 0x1DBC, 0x20C5, 0x22C2, 0x203F, 0x1F3B
	DW	0x1DBE, 0x2248, 0x2243, 0x23CE, 0x28D0, 0x27CD, 0x2442, 0x1DB8, 0x1D3D, 0x2045, 0x2447, 0x21BD, 0x1C38, 0x1DBD, 0x1FC4, 0x2343
	DW	0x224B, 0x27D3, 0x2AD2, 0x25C4, 0x1DB5, 0x19B6, 0x1E44, 0x24CB, 0x2441, 0x1CB4, 0x1A37, 0x1E41, 0x23C4, 0x224A, 0x27D2, 0x2AD6
	DW	0x2947, 0x1D32, 0x1832, 0x1CC1, 0x2550, 0x26C4, 0x1DB5, 0x18B4, 0x1CBD, 0x21C7, 0x234C, 0x28D2, 0x2D5F, 0x2943, 0x1D2F, 0x162F
	DW	0x1A42, 0x28D2, 0x26C7, 0x1EB4, 0x17AF, 0x1ABC, 0x22C7, 0x22D1, 0x2CD8, 0x3062, 0x2841, 0x19A6, 0x14B0, 0x1B48, 0x2BD7, 0x2946
	DW	0x1BB1, 0x172F, 0x1ABC, 0x22CA, 0x24D3, 0x2CDF, 0x3563, 0x253A, 0x17A4, 0x12AC, 0x1CD1, 0x2E57, 0x2846, 0x1BAD, 0x152F, 0x1C3D
	DW	0x234A, 0x24D3, 0x2E65, 0x37E1, 0x2237, 0x1621, 0x112A, 0x1E55, 0x2ED6, 0x2845, 0x1AAA, 0x142D, 0x1BC0, 0x2346, 0x2659, 0x2FE9
	DW	0x385A, 0x20B5, 0x139E, 0x11AB, 0x215A, 0x2DD5, 0x2841, 0x1929, 0x132E, 0x1BBD, 0x234B, 0x25D7, 0x316B, 0x38DA, 0x1DB0, 0x139C
	DW	0x0FAC, 0x21DC, 0x2ED3, 0x27C3, 0x1825, 0x1431, 0x1CBD, 0x21C8, 0x275B, 0x30EF, 0x39D9, 0x1DB0, 0x119C, 0x102B, 0x225D, 0x2ED5
	DW	0x28C2, 0x18A6, 0x13B1, 0x1CBB, 0x20CB, 0x295C, 0x32F3, 0x39D7, 0x1CAC, 0x119C, 0x0EAC, 0x24DE, 0x2ED5, 0x28C3, 0x1823, 0x12B2
	DW	0x1E3D, 0x214B, 0x29DE, 0x31F0, 0x3A58, 0x1D2D, 0x111C, 0x0F2A, 0x22DD, 0x2DD4, 0x2945, 0x1926, 0x14B1, 0x1ABB, 0x2147, 0x2A61
	DW	0x33F8, 0x3AD1, 0x1D2D, 0x0E17, 0x0DA9, 0x24DD, 0x2C57, 0x2A42, 0x18A7, 0x142F, 0x1AB8, 0x224B, 0x29E0, 0x367B, 0x38CD, 0x1B2C
	DW	0x0E94, 0x0CAD, 0x255A, 0x2B56, 0x2A43, 0x17A8, 0x15AD, 0x1ABB, 0x2049, 0x2BE1, 0x3AFF, 0x32C7, 0x1CA8, 0x0C93, 0x0D34, 0x2754
	DW	0x2ADA, 0x293F, 0x17AD, 0x18B0, 0x1839, 0x224B, 0x2BE6, 0x3E7E, 0x2FC2, 0x1BA7, 0x0A90, 0x0EBA, 0x27D1, 0x2A5A, 0x28BC, 0x17B0
	DW	0x1AB3, 0x1839, 0x234D, 0x2C68, 0x3E79, 0x2DC3, 0x1BA7, 0x0A92, 0x10BD, 0x264D, 0x29D9, 0x27BD, 0x19B3, 0x1B33, 0x193E, 0x234C
	DW	0x2C70, 0x3F6E, 0x2944, 0x1C24, 0x0914, 0x14BF, 0x22C9, 0x2A57, 0x243A, 0x1C3A, 0x1B32, 0x19C0, 0x234C, 0x2D72, 0x3C65, 0x2743
	DW	0x1B23, 0x0999, 0x173C, 0x2048, 0x2952, 0x2239, 0x1DBC, 0x1B33, 0x1CC2, 0x234D, 0x2F72, 0x38DB, 0x2643, 0x1AA0, 0x0B20, 0x193A
	DW	0x1EC7, 0x28CD, 0x203B, 0x203E, 0x1C37, 0x1EC2, 0x23CD, 0x3072, 0x3555, 0x26C4, 0x19A1, 0x0D25, 0x1AB7, 0x1DC8, 0x27C9, 0x203E
	DW	0x21C2, 0x1D39, 0x20C5, 0x23CE, 0x306D, 0x31D1, 0x25C5, 0x1AA3, 0x102B, 0x1B36, 0x1D46, 0x2646, 0x1FC2, 0x23C2, 0x1D3C, 0x21C7
	DW	0x24CF, 0x316B, 0x2ECF, 0x2643, 0x1A25, 0x11AF, 0x1B35, 0x1D47, 0x2543, 0x1FC4, 0x2444, 0x1F3D, 0x234B, 0x2450, 0x31E5, 0x2BCE
	DW	0x24C3, 0x1AA7, 0x13B4, 0x1B34, 0x1DC5, 0x2442, 0x1FC6, 0x2543, 0x1F40, 0x234A, 0x24D1, 0x3061, 0x29CC, 0x2441, 0x1A29, 0x1534
	DW	0x1B33, 0x1DC4, 0x2240, 0x20C6, 0x24C3, 0x2042, 0x244A, 0x24D4, 0x2FDA, 0x27CA, 0x22BE, 0x19AA, 0x1735, 0x1A34, 0x1EC2, 0x213F
	DW	0x2147, 0x2443, 0x2143, 0x2449, 0x2454, 0x2ED6, 0x274B, 0x233E, 0x1A2C, 0x1835, 0x1934, 0x1E40, 0x203F, 0x20C7, 0x24C3, 0x21C6
	DW	0x2448, 0x24D0, 0x2C54, 0x264B, 0x23BF, 0x1BB0, 0x1937, 0x1A34, 0x1E3F, 0x2040, 0x20C6, 0x2444, 0x2247, 0x23CA, 0x254F, 0x2B54
	DW	0x26CB, 0x2441, 0x1D33, 0x19B6, 0x1AB5, 0x1DBE, 0x1FC0, 0x20C4, 0x2446, 0x22C7, 0x2348, 0x254D, 0x29D3, 0x26CB, 0x2442, 0x1DB6
	DW	0x1A36, 0x1B36, 0x1CBD, 0x1F3F, 0x2042, 0x2346, 0x22C5, 0x2347, 0x24CA, 0x2852, 0x274A, 0x2444, 0x1F38, 0x1A36, 0x1BB6, 0x1C3C
	DW	0x1F3F, 0x1FC0, 0x2246, 0x2245, 0x2346, 0x2448, 0x26D1, 0x27CB, 0x2546, 0x20BC, 0x1BB7, 0x1CB8, 0x1C3B, 0x1F3F, 0x1FC0, 0x2145
	DW	0x22C5, 0x2346, 0x2348, 0x25CF, 0x284D, 0x2549, 0x223F, 0x1DB9, 0x1CBA, 0x1CBB, 0x1F3F, 0x1F3F, 0x2144, 0x2346, 0x2346, 0x2346
	DW	0x24CC, 0x274D, 0x25C9, 0x23C3, 0x1F3C, 0x1E3C, 0x1DBC, 0x1F3F, 0x1FBF, 0x2043, 0x22C5, 0x2346, 0x23C7, 0x244A, 0x26CE, 0x2649
	DW	0x2446, 0x213E, 0x1EBD, 0x1EBD, 0x1EBE, 0x1FBF, 0x1FC1, 0x21C4, 0x2245, 0x2346, 0x2347, 0x254C, 0x264A, 0x2446, 0x2240, 0x1F3D
	DW	0x1EBE, 0x1F3E, 0x1F3F, 0x1FC0, 0x2142, 0x21C4, 0x22C5, 0x2346, 0x23CA, 0x25CA, 0x24C7, 0x2343, 0x203F, 0x1FBE, 0x1F3E, 0x1F3F
	DW	0x1F3F, 0x2041, 0x2143, 0x2244, 0x22C6, 0x2347, 0x24C9, 0x24C8, 0x2345, 0x2242, 0x2040, 0x2040, 0x1FBF, 0x2040, 0x1FBF, 0x20C2
	DW	0x2143, 0x2245, 0x2346, 0x2348, 0x24C9, 0x2447, 0x2345, 0x21C2, 0x2142, 0x20C1, 0x20C1, 0x20C0, 0x2041, 0x2142, 0x21C5, 0x2346
	DW	0x2346, 0x2448, 0x23C8, 0x23C7, 0x2345, 0x2243, 0x21C2, 0x2142, 0x20C1, 0x2040, 0x20C1, 0x2143, 0x2244, 0x22C5, 0x22C5, 0x22C6
	DW	0x2346, 0x2345, 0x22C4, 0x2243, 0x21C3, 0x2142, 0x20C1, 0x20C0, 0x2041, 0x20C2, 0x21C3, 0x2244, 0x2244, 0x22C5, 0x22C5, 0x22C4
	DW	0x2244, 0x2243, 0x21C2, 0x2141, 0x20C1, 0x20C1, 0x20C1, 0x2142, 0x2142, 0x21C3, 0x21C4, 0x2244, 0x2245, 0x22C5, 0x2244, 0x21C3
	DW	0x21C2, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x21C3, 0x21C3, 0x21C4, 0x2244, 0x2245, 0x22C4, 0x2244, 0x2243, 0x21C3, 0x21C3
	DW	0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x2244, 0x2244, 0x2244, 0x2244, 0x2244, 0x2244, 0x21C3, 0x2244, 0x21C4, 0x2244, 0x2243
	DW	0x21C4, 0x21C3, 0x21C4, 0x2243, 0x21C4, 0x2244, 0x2244, 0x2244, 0x21C4, 0x2244, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3
	DW	0x21C0
SMP1	DW	0x21C1, 0x2040, 0x2040, 0x20C3, 0x2246, 0x23C7, 0x2449, 0x254B, 0x264C, 0x264A, 0x2446, 0x21C0, 0x1F3E, 0x1F3F, 0x2041, 0x2143
	DW	0x2244, 0x22C6, 0x23CA, 0x2752, 0x2AD5, 0x294C, 0x2340, 0x1EBD, 0x1F41, 0x2244, 0x21C1, 0x1FBD, 0x1F3F, 0x20C3, 0x23CB, 0x28D6
	DW	0x2C56, 0x28CA, 0x213D, 0x1E3F, 0x22C9, 0x25C9, 0x21BC, 0x1BB4, 0x1ABA, 0x1F43, 0x22C7, 0x254D, 0x28D4, 0x2A51, 0x25C3, 0x1EBB
	DW	0x1E42, 0x23CA, 0x24C5, 0x1EB6, 0x18B1, 0x1A3A, 0x2044, 0x23CA, 0x26D2, 0x2A53, 0x2746, 0x1EB8, 0x1BBA, 0x2149, 0x26CD, 0x243F
	DW	0x1C33, 0x1935, 0x1D40, 0x2246, 0x2346, 0x2348, 0x254C, 0x25C8, 0x213B, 0x1C37, 0x1D40, 0x22C8, 0x23C3, 0x1FBB, 0x1CBB, 0x2048
	DW	0x29DD, 0x2FD9, 0x26BE, 0x1930, 0x1A40, 0x2758, 0x2B4D, 0x1DAC, 0x1226, 0x18C1, 0x2651, 0x26C5, 0x224B, 0x2C60, 0x2FD3, 0x1FAC
	DW	0x14B1, 0x235C, 0x34E8, 0x2DC1, 0x1398, 0x0CA6, 0x1E4D, 0x2AD2, 0x2338, 0x1935, 0x2153, 0x3166, 0x2F4C, 0x1D31, 0x19C0, 0x2755
	DW	0x2943, 0x1928, 0x13B0, 0x1EC6, 0x2445, 0x20C7, 0x2CEB, 0x36DD, 0x2021, 0x0A22, 0x1F62, 0x3CF4, 0x30C6, 0x16A0, 0x11A8, 0x1A3B
	DW	0x1FC0, 0x2141, 0x203C, 0x1D3B, 0x214C, 0x2D63, 0x30D5, 0x2236, 0x1837, 0x21CF, 0x2A4D, 0x1E2D, 0x1124, 0x17BD, 0x244C, 0x24CB
	DW	0x2BE9, 0x355C, 0x1EA2, 0x0925, 0x21E8, 0x3E77, 0x2E44, 0x17A6, 0x142B, 0x17B4, 0x1DC2, 0x24C8, 0x21B9, 0x1A34, 0x204F, 0x2F65
	DW	0x32D7, 0x243C, 0x1C3A, 0x224A, 0x274C, 0x21B9, 0x1728, 0x1431, 0x1EC9, 0x2855, 0x2E6D, 0x375C, 0x1F23, 0x0A25, 0x24E8, 0x3BF3
	DW	0x2BC4, 0x1BB4, 0x17AD, 0x11A8, 0x1A46, 0x2953, 0x21B1, 0x132E, 0x2057, 0x3266, 0x31D6, 0x2542, 0x1EBA, 0x1FC1, 0x24CE, 0x26C0
	DW	0x1820, 0x0E26, 0x1D4D, 0x2AD2, 0x26D6, 0x3569, 0x2AB2, 0x0C12, 0x19DA, 0x3B77, 0x31C2, 0x1C35, 0x1B2F, 0x119A, 0x12BC, 0x27D7
	DW	0x2531, 0x10A5, 0x1DD5, 0x3267, 0x30D6, 0x2542, 0x1E37, 0x1DC2, 0x2656, 0x2AC5, 0x1799, 0x081C, 0x1A4B, 0x2C52, 0x22C1, 0x2A70
	DW	0x3B59, 0x170F, 0x0A3C, 0x35FF, 0x3958, 0x1D3C, 0x2241, 0x1595, 0x0727, 0x27E5, 0x2F41, 0x0F9A, 0x184F, 0x336A, 0x325C, 0x2AD0
	DW	0x233C, 0x1AC0, 0x26DF, 0x34DD, 0x201F, 0x048B, 0x11C1, 0x2B5A, 0x26BD, 0x1CC6, 0x2F75, 0x37CC, 0x161F, 0x18D0, 0x36EB, 0x2E4C
	DW	0x234D, 0x24B1, 0x0987, 0x0BC0, 0x2FDE, 0x222B, 0x0F2F, 0x2254, 0x2C5E, 0x34E9, 0x2EC1, 0x1623, 0x1C54, 0x346A, 0x2E3F, 0x1596
	DW	0x0897, 0x153B, 0x27D1, 0x22B8, 0x1833, 0x2460, 0x3B6E, 0x2832, 0x1332, 0x25E0, 0x2ED4, 0x26CA, 0x2334, 0x0C09, 0x09B1, 0x2758
	DW	0x24B6, 0x1733, 0x20D1, 0x30EE, 0x324F, 0x1CAF, 0x19C6, 0x2B5D, 0x2DD9, 0x26C6, 0x1511, 0x0518, 0x1C54, 0x2D4A, 0x1CAE, 0x1740
	DW	0x2BEC, 0x3DE3, 0x232E, 0x16BB, 0x29DE, 0x2E56, 0x2ACF, 0x22A7, 0x080F, 0x1140, 0x2AD2, 0x223A, 0x1C3D, 0x265A, 0x3670, 0x2C40
	DW	0x1835, 0x2359, 0x2E59, 0x2CD6, 0x29BE, 0x0C04, 0x07AF, 0x28DF, 0x273C, 0x1A36, 0x1F4C, 0x2CEE, 0x3857, 0x1FAE, 0x18C4, 0x2C5B
	DW	0x2BD6, 0x29CD, 0x1B14, 0x0497, 0x19CA, 0x28C6, 0x1FBC, 0x1E3E, 0x23D7, 0x386D, 0x2938, 0x15B3, 0x2559, 0x2C53, 0x29CC, 0x2129
	DW	0x0891, 0x123B, 0x2547, 0x1F3B, 0x1E3B, 0x2048, 0x2D71, 0x33CB, 0x192C, 0x1CCF, 0x2BD3, 0x27D4, 0x2943, 0x118C, 0x07A8, 0x1F4A
	DW	0x22C2, 0x2144, 0x1FBF, 0x24DF, 0x3A63, 0x2331, 0x1944, 0x2BD8, 0x284D, 0x274A, 0x1E24, 0x0CA3, 0x1A3F, 0x2240, 0x2144, 0x22C1
	DW	0x2352, 0x31EE, 0x2E44, 0x1CBD, 0x25D4, 0x29CE, 0x28D0, 0x2334, 0x109E, 0x14B7, 0x1E41, 0x20C6, 0x244B, 0x28DF, 0x34E6, 0x2739
	DW	0x18BD, 0x26D6, 0x2AD4, 0x2D59, 0x2534, 0x0F9D, 0x1536, 0x1DBC, 0x1FC5, 0x2443, 0x1CBA, 0x2354, 0x2F5C, 0x2BCF, 0x27CE, 0x2545
	DW	0x21C4, 0x2240, 0x1BAF, 0x17B4, 0x1BB7, 0x1BBA, 0x20C7, 0x26D6, 0x30E5, 0x2BC7, 0x1DBA, 0x2048, 0x24C9, 0x27D6, 0x2B4C, 0x1DAE
	DW	0x1631, 0x1AB5, 0x1A36, 0x1E41, 0x1FBC, 0x1EC3, 0x254D, 0x26CA, 0x2650, 0x28D0, 0x26CD, 0x27CD, 0x23BF, 0x1CBA, 0x1EBE, 0x1DB9
	DW	0x1CBA, 0x1CB7, 0x1CC1, 0x2552, 0x294F, 0x26CF, 0x29D3, 0x2953, 0x2AD5, 0x294A, 0x2140, 0x203E, 0x1DB8, 0x1BB9, 0x1D38, 0x1AB7
	DW	0x1DC1, 0x2243, 0x22C9, 0x2752, 0x2A57, 0x2D5C, 0x2D54, 0x25C7, 0x22C4, 0x203C, 0x1D39, 0x1C35, 0x1931, 0x1B3D, 0x2246, 0x23C9
	DW	0x2650, 0x29D5, 0x2C5A, 0x2DD6, 0x28CC, 0x24C8, 0x21BE, 0x1DBA, 0x1DB9, 0x1AB2, 0x19B8, 0x1EBF, 0x2040, 0x21C6, 0x24CA, 0x26D1
	DW	0x2A55, 0x294F, 0x26CC, 0x2545, 0x203E, 0x1EBC, 0x1C34, 0x1934, 0x1C3C, 0x1E3C, 0x1F42, 0x23C9, 0x25CE, 0x2955, 0x2A51, 0x274E
	DW	0x26CA, 0x22C1, 0x1F3D, 0x1E38, 0x1A32, 0x1AB9, 0x1E3D, 0x1F41, 0x22C8, 0x254D, 0x2853, 0x2B56, 0x2A54, 0x2950, 0x26C7, 0x2242
	DW	0x203C, 0x1CB6, 0x1AB7, 0x1C39, 0x1DBD, 0x2042, 0x21C4, 0x23CB, 0x2751, 0x28D2, 0x29D3, 0x294F, 0x264A, 0x24C6, 0x213F, 0x1E3B
	DW	0x1D3A, 0x1D3C, 0x1EBE, 0x1FC0, 0x21C6, 0x24CB, 0x264D, 0x27D0, 0x284F, 0x274D, 0x264A, 0x23C4, 0x20BD, 0x1DBA, 0x1D3B, 0x1E3C
	DW	0x1DBB, 0x1E3F, 0x2144, 0x2348, 0x254D, 0x26CD, 0x26CD, 0x26CC, 0x2547, 0x22C3, 0x20BE, 0x1DB9, 0x1D3B, 0x1D39, 0x1C3A, 0x1EC0
	DW	0x2143, 0x2247, 0x24CA, 0x254A, 0x25CC, 0x264B, 0x24C7, 0x2343, 0x20BF, 0x1F3E, 0x1EBC, 0x1D3A, 0x1DBD, 0x1F3F, 0x20C4, 0x2348
	DW	0x2449, 0x254C, 0x26CD, 0x264A, 0x254A, 0x23C5, 0x21C2, 0x21C2, 0x1FBD, 0x1EBE, 0x1FC0, 0x2040, 0x2145, 0x2347, 0x2449, 0x25CB
	DW	0x264B, 0x25CB, 0x25C9, 0x2446, 0x2346, 0x22C3, 0x2141, 0x2040, 0x2040, 0x2143, 0x21C4, 0x2245, 0x23C8, 0x24C9, 0x24C9, 0x24C9
	DW	0x2447, 0x2346, 0x2345, 0x21C3, 0x2141, 0x20C0, 0x2041, 0x20C2, 0x2142, 0x21C4, 0x2244, 0x22C5, 0x22C6, 0x2345, 0x22C5, 0x22C5
	DW	0x22C4, 0x21C2, 0x20C1, 0x2141, 0x20C1, 0x2041, 0x2041, 0x2142, 0x21C3, 0x2143, 0x21C4, 0x2244, 0x21C4, 0x2244, 0x2243, 0x21C2
	DW	0x21C2, 0x2142, 0x2142, 0x20C0
SMP2	DW	0x2243, 0x2345, 0x21C4, 0x2243, 0x2243, 0x21C4, 0x20C2, 0x21C3, 0x2143, 0x2144, 0x2143, 0x21C4, 0x2245, 0x2246, 0x22C6, 0x2347
	DW	0x22C6, 0x2343, 0x21C3, 0x2144, 0x21C5, 0x2346, 0x2347, 0x23C7, 0x23C9, 0x254A, 0x254B, 0x254B, 0x254A, 0x254A, 0x254A, 0x25CA
	DW	0x254B, 0x25CA, 0x25CC, 0x25CB, 0x254A, 0x2549, 0x254A, 0x24C9, 0x24C9, 0x24C8, 0x24C8, 0x23C6, 0x23C5, 0x22C4, 0x22C5, 0x22C6
	DW	0x22C6, 0x2347, 0x2347, 0x23C8, 0x23C7, 0x2345, 0x21C1, 0x1FBD, 0x1DB9, 0x1CB8, 0x1C38, 0x1CBB, 0x1F41, 0x2247, 0x25CD, 0x28D5
	DW	0x2BD6, 0x2B54, 0x2849, 0x21BD, 0x1C33, 0x1931, 0x1933, 0x1B39, 0x1E3E, 0x20C5, 0x24CB, 0x26D3, 0x2CDD, 0x30DF, 0x2E59, 0x27C4
	DW	0x1E34, 0x17AC, 0x16B2, 0x1AB9, 0x1F40, 0x2143, 0x22C8, 0x2449, 0x2854, 0x2BDF, 0x30DC, 0x2CD0, 0x233B, 0x182B, 0x15A9, 0x1735
	DW	0x1CBC, 0x1F3F, 0x20C1, 0x21C6, 0x23CA, 0x2853, 0x2EE3, 0x2DD8, 0x29C5, 0x1CAE, 0x1428, 0x132A, 0x1AB8, 0x1E40, 0x20C2, 0x2145
	DW	0x23C8, 0x24D0, 0x29DA, 0x325E, 0x2C54, 0x233A, 0x1726, 0x13A7, 0x14B5, 0x1DBE, 0x20C2, 0x2246, 0x22C9, 0x264B, 0x28D5, 0x2DE8
	DW	0x3056, 0x2AC8, 0x1C2E, 0x13AA, 0x14A9, 0x1C3D, 0x1EC2, 0x22C4, 0x2346, 0x254B, 0x25D1, 0x2C5E, 0x35E1, 0x2C56, 0x23B7, 0x16A6
	DW	0x13A8, 0x1437, 0x1EBD, 0x20C5, 0x2144, 0x23C9, 0x25CB, 0x28D6, 0x2DEB, 0x31D3, 0x2A47, 0x1A29, 0x1225, 0x14A6, 0x1BBF, 0x1E3F
	DW	0x22C3, 0x22C4, 0x254E, 0x2551, 0x2CDB, 0x3664, 0x29D6, 0x2432, 0x1625, 0x12AA, 0x1438, 0x20BC, 0x20C7, 0x2144, 0x23C9, 0x25CA
	DW	0x28D9, 0x2FF0, 0x31D1, 0x2BC6, 0x16A8, 0x11A4, 0x13A6, 0x1C41, 0x1CC0, 0x2340, 0x2147, 0x254A, 0x2451, 0x2D60, 0x37DF, 0x28D7
	DW	0x20AA, 0x13A0, 0x1126, 0x13B9, 0x1FB9, 0x20C5, 0x1FC1, 0x22C9, 0x2548, 0x28D9, 0x3074, 0x2F4F, 0x2D42, 0x13A9, 0x0FA3, 0x12A6
	DW	0x1DC1, 0x1B44, 0x23BD, 0x20C5, 0x24CB, 0x2352, 0x2E5E, 0x39E2, 0x27DA, 0x21A7, 0x149E, 0x10A6, 0x12B8, 0x2136, 0x2147, 0x1EC1
	DW	0x2247, 0x2646, 0x285D, 0x2EF3, 0x32CC, 0x2D46, 0x1229, 0x0F1F, 0x12A3, 0x1B43, 0x19C2, 0x243C, 0x1FC6, 0x22C8, 0x22CE, 0x2EDF
	DW	0x3AE1, 0x28DB, 0x21A3, 0x151C, 0x0EA2, 0x11B5, 0x2033, 0x21C6, 0x1D3F, 0x2245, 0x2445, 0x27DC, 0x2EF9, 0x2F4D, 0x2EC3, 0x10AB
	DW	0x0E1E, 0x1122, 0x1B40, 0x1842, 0x2339, 0x1FC5, 0x22C8, 0x21CF, 0x2ED7, 0x3B68, 0x265C, 0x25A5, 0x161D, 0x0EA3, 0x0FB0, 0x2130
	DW	0x1FC8, 0x1D3E, 0x22C4, 0x2546, 0x275E, 0x2D75, 0x34CB, 0x2ECC, 0x11AD, 0x101C, 0x11A2, 0x18C3, 0x1840, 0x2439, 0x1EC7, 0x21C8
	DW	0x22CD, 0x2E58, 0x39F3, 0x265D, 0x2A28, 0x16A4, 0x0E24, 0x10AC, 0x2231, 0x1ECA, 0x1EBB, 0x2544, 0x24C7, 0x255B, 0x2C65, 0x3FD0
	DW	0x2A5E, 0x1A29, 0x161B, 0x1323, 0x12C3, 0x1C34, 0x2543, 0x1CC7, 0x224B, 0x2448, 0x2BDA, 0x2F7F, 0x2ECF, 0x3041, 0x13AF, 0x0E22
	DW	0x1221, 0x1CBD, 0x1845, 0x2239, 0x2144, 0x2349, 0x22D1, 0x2E59, 0x3C6E, 0x25DF, 0x2829, 0x1722, 0x0EA5, 0x0FAE, 0x20AF, 0x1EC8
	DW	0x1DBC, 0x2446, 0x2446, 0x25D8, 0x2B65, 0x3F56, 0x2960, 0x1EA8, 0x161F, 0x12A1, 0x11BC, 0x1C30, 0x22C4, 0x1BC4, 0x2348, 0x24C9
	DW	0x2958, 0x29F3, 0x3BC9, 0x2D5D, 0x18A9, 0x1523, 0x129E, 0x1643, 0x1835, 0x263E, 0x1C47, 0x23C9, 0x2448, 0x2B57, 0x2CFC, 0x354A
	DW	0x3151, 0x15AE, 0x13A3, 0x121F, 0x1A3F, 0x16C0, 0x2539, 0x1FC9, 0x234B, 0x24CC, 0x2CD3, 0x2FFF, 0x2ECC, 0x32C9, 0x14B2, 0x12A4
	DW	0x1121, 0x1C3B, 0x16C6, 0x22B8, 0x2147, 0x244B, 0x2350, 0x2C4F, 0x32FC, 0x2B51, 0x30C2, 0x162F, 0x12A6, 0x10A3, 0x1DB7, 0x1844
	DW	0x213A, 0x20C5, 0x254A, 0x2351, 0x2C53, 0x3476, 0x29D3, 0x2EBD, 0x15AD, 0x1224, 0x1026, 0x1DB6, 0x19C5, 0x213C, 0x22C8, 0x25CA
	DW	0x24D2, 0x2B54, 0x3672, 0x27D8, 0x2E39, 0x16B0, 0x1324, 0x10AB, 0x1DB2, 0x1B46, 0x213B, 0x23CB, 0x25CB, 0x25D6, 0x2BD7, 0x3969
	DW	0x265B, 0x2AB3, 0x182D, 0x1325, 0x1130, 0x1E30, 0x1D48, 0x1FBE, 0x23CA, 0x264A, 0x2658, 0x2BDF, 0x3ADF, 0x27DF, 0x24B0, 0x18AA
	DW	0x1325, 0x1235, 0x1C31, 0x20C5, 0x1EC2, 0x24CC, 0x25CA, 0x2957, 0x29E5, 0x3856, 0x29DA, 0x2231, 0x182B, 0x1422, 0x1438, 0x1A33
	DW	0x2142, 0x1EC3, 0x24CB, 0x25CA, 0x2957, 0x2AE6, 0x3652, 0x2957, 0x1F2F, 0x182A, 0x1323, 0x15B7, 0x19B4, 0x2140, 0x1E43, 0x2549
	DW	0x24CC, 0x2953, 0x2A66, 0x34CF, 0x29D7, 0x1F2F, 0x192C, 0x1323, 0x16B7, 0x18B4, 0x2140, 0x1DC4, 0x25CA, 0x24CC, 0x2A54, 0x2AE6
	DW	0x3351, 0x29D5, 0x1FB2, 0x192E, 0x1426, 0x17B8, 0x19B6, 0x2141, 0x1E45, 0x25CB, 0x24CE, 0x2A53, 0x2A64, 0x3252, 0x2956, 0x21B4
	DW	0x1AB2, 0x1527, 0x18B8, 0x1A36, 0x20C1, 0x1EC3, 0x264B, 0x24CE, 0x29D3, 0x2A60, 0x31D6, 0x2954, 0x2337, 0x1A33, 0x1628, 0x1837
	DW	0x1AB7, 0x2042, 0x1FC3, 0x254C, 0x25CC, 0x2954, 0x29DE, 0x30D7, 0x29D4, 0x243C, 0x1B34, 0x172B, 0x17B5, 0x1B37, 0x1EC1, 0x2042
	DW	0x24CD, 0x254C, 0x28D2, 0x295A, 0x2ED5, 0x28D1, 0x243C, 0x1B34, 0x172B, 0x17B4, 0x1AB7, 0x1E40, 0x1FC2, 0x244A, 0x24CC, 0x2750
	DW	0x2856, 0x2D55, 0x28D1, 0x24BE, 0x1CB6, 0x18AE, 0x1834, 0x1B37, 0x1E40, 0x2042, 0x23CA, 0x24CC, 0x27CF, 0x28D7, 0x2D54, 0x28D1
	DW	0x24BF, 0x1DB7, 0x18AF, 0x1935, 0x1BB9, 0x1EC0, 0x20C3, 0x23CA, 0x254C, 0x27CF, 0x2855, 0x2C53, 0x2850, 0x24C0, 0x1E39, 0x1A31
	DW	0x19B6, 0x1BB9, 0x1EC0, 0x20C2, 0x23CB, 0x24CB, 0x27CF, 0x2752, 0x2B51, 0x274F, 0x2542, 0x1FBB, 0x1C34, 0x1A37, 0x1CB8, 0x1EC0
	DW	0x2041, 0x22C8, 0x2449, 0x25CD, 0x264F, 0x29D0, 0x26CE, 0x25C5, 0x203E, 0x1DB7, 0x1AB7, 0x1CB8, 0x1D3E, 0x1FBF, 0x20C5, 0x23C7
	DW	0x244A, 0x24CA, 0x274F, 0x264B, 0x2648, 0x21C0, 0x1F3B, 0x1C38, 0x1D3A, 0x1D3C, 0x1F3E, 0x2043, 0x22C6, 0x2347, 0x24C8, 0x254C
	DW	0x26CB, 0x25CA, 0x2444, 0x2140, 0x1EBB, 0x1E3C, 0x1E3C, 0x1F3F, 0x2041, 0x2144, 0x22C5, 0x2347, 0x2448, 0x254B, 0x25C9, 0x24C8
	DW	0x2343, 0x21C1, 0x203F, 0x1FBF, 0x1FBE, 0x1FC0, 0x2041, 0x2143, 0x2245, 0x22C6, 0x23C7, 0x2449, 0x24C8, 0x2447, 0x22C4, 0x2243
	DW	0x2141, 0x20C1, 0x2040, 0x2040, 0x2041, 0x20C2, 0x21C4, 0x22C5, 0x2347, 0x23C8, 0x2448, 0x23C6, 0x2346, 0x2244, 0x2243, 0x2143
	DW	0x2141, 0x2041, 0x2040, 0x20C2, 0x2143, 0x2245, 0x22C5, 0x22C5, 0x22C6, 0x22C5, 0x22C5, 0x22C5, 0x2244, 0x21C3, 0x2142, 0x2141
	DW	0x20C1, 0x20C2, 0x2140
SMP3	DW	0x2346, 0x2347, 0x2345, 0x2348, 0x2446, 0x2348, 0x22C2, 0x21C3, 0x203F, 0x1FBF, 0x1FBF, 0x20C3, 0x22C5, 0x22C7, 0x2651, 0x29D2
	DW	0x28D0, 0x27CB, 0x21BD, 0x1DB9, 0x1B37, 0x1CBC, 0x1FBD, 0x1FC2, 0x2244, 0x21C2, 0x23D2, 0x2F60, 0x2CD8, 0x2ED0, 0x1D30, 0x17AF
	DW	0x172F, 0x1C45, 0x23C2, 0x2148, 0x24C1, 0x1DBB, 0x1F44, 0x2559, 0x35E4, 0x2D5F, 0x2737, 0x1724, 0x122B, 0x17BA, 0x234A, 0x2345
	DW	0x2446, 0x203C, 0x1CBC, 0x22CD, 0x31F4, 0x30DA, 0x2F43, 0x17A7, 0x0F25, 0x1732, 0x1F4C, 0x26C3, 0x234B, 0x223F, 0x1DB8, 0x1FC7
	DW	0x2869, 0x3960, 0x2FDB, 0x1F2D, 0x119E, 0x1229, 0x18C0, 0x26C9, 0x2048, 0x23BD, 0x1DB8, 0x1B3A, 0x214F, 0x3673, 0x2FDE, 0x2E3F
	DW	0x141D, 0x0D21, 0x14B2, 0x204E, 0x24C1, 0x23C6, 0x1E38, 0x1B33, 0x1C40, 0x25EB, 0x3C64, 0x2FDB, 0x2126, 0x0C17, 0x0E27, 0x18BD
	DW	0x27CB, 0x2146, 0x23BE, 0x1AB3, 0x1A38, 0x2049, 0x33FD, 0x36E0, 0x2E47, 0x1518, 0x0B1A, 0x13B0, 0x1DCE, 0x2745, 0x244A, 0x1FB7
	DW	0x1C33, 0x1BC2, 0x2469, 0x3FEE, 0x3263, 0x26AD, 0x0E19, 0x0CA4, 0x17C1, 0x2A50, 0x254D, 0x25C0, 0x1BB8, 0x1BB8, 0x1F44, 0x2FF9
	DW	0x38EA, 0x36D6, 0x1B25, 0x0D16, 0x0E27, 0x1DCC, 0x264D, 0x27CC, 0x22BA, 0x1C35, 0x1939, 0x21D6, 0x3A7A, 0x37EC, 0x2F41, 0x149A
	DW	0x0A98, 0x1233, 0x234F, 0x274E, 0x2747, 0x1EB9, 0x1B31, 0x1BBF, 0x24E7, 0x3D70, 0x35E2, 0x25B1, 0x0E95, 0x0B9C, 0x13BD, 0x264B
	DW	0x26CF, 0x26C1, 0x1A38, 0x1A2D, 0x1D45, 0x2C74, 0x39EC, 0x3454, 0x1CA4, 0x0C11, 0x0BA2, 0x1BCA, 0x254F, 0x2949, 0x213C, 0x19B1
	DW	0x1A34, 0x1E4A, 0x2FF2, 0x38EF, 0x3352, 0x1DA4, 0x0D16, 0x0CA3, 0x1B45, 0x24CF, 0x284F, 0x23BA, 0x1C37, 0x1ABB, 0x22D1, 0x35F7
	DW	0x3867, 0x2FCD, 0x151E, 0x0E19, 0x0F2F, 0x2249, 0x26CF, 0x284A, 0x1FBB, 0x1D35, 0x1B3F, 0x22D4, 0x33EE, 0x3870, 0x2CC8, 0x1CA0
	DW	0x0D1B, 0x0EAB, 0x1D43, 0x264F, 0x26CE, 0x21BA, 0x1EB8, 0x1C42, 0x2459, 0x37EB, 0x3465, 0x2ABD, 0x15A3, 0x0D9A, 0x1133, 0x1EC2
	DW	0x25CF, 0x2645, 0x2140, 0x1CB4, 0x1F45, 0x2155, 0x35E8, 0x335F, 0x29C1, 0x13A2, 0x1018, 0x0FB4, 0x1CBE, 0x24CA, 0x2542, 0x1F42
	DW	0x1CB5, 0x20C6, 0x23DB, 0x36E9, 0x2D5B, 0x2B30, 0x12AA, 0x0E19, 0x1636, 0x1BC3, 0x24CB, 0x22C3, 0x233E, 0x1AC1, 0x2139, 0x27DD
	DW	0x2D66, 0x3758, 0x29C9, 0x1727, 0x101B, 0x132B, 0x19C6, 0x22C7, 0x2ACA, 0x2249, 0x2142, 0x22C7, 0x28E5, 0x34E0, 0x2FE3, 0x26B6
	DW	0x1B2B, 0x0FA5, 0x17B2, 0x1DC5, 0x2449, 0x254B, 0x23C1, 0x22C2, 0x1F4A, 0x26D8, 0x31E6, 0x31DE, 0x2B42, 0x1AAC, 0x1220, 0x132F
	DW	0x1BBF, 0x234D, 0x26C9, 0x26C8, 0x20C5, 0x2348, 0x27DE, 0x33E1, 0x2CE6, 0x2732, 0x1FAC, 0x0CAA, 0x182B, 0x1DC5, 0x21C8, 0x25C9
	DW	0x22C2, 0x2342, 0x1F4B, 0x2753, 0x30E7, 0x2E5D, 0x2D40, 0x1AB1, 0x1221, 0x13AD, 0x1A3C, 0x21CA, 0x24C9, 0x2544, 0x20C6, 0x21C6
	DW	0x26D7, 0x3163, 0x2A64, 0x2A39, 0x21B0, 0x10AB, 0x152A, 0x1C3D, 0x2046, 0x24C9, 0x2346, 0x2440, 0x20CB, 0x25D0, 0x2FEA, 0x2C5C
	DW	0x3243, 0x1AC0, 0x139F, 0x182B, 0x183D, 0x2047, 0x2449, 0x2645, 0x21CC, 0x21C5, 0x29D2, 0x2DEA, 0x29E0, 0x2EBF, 0x203A, 0x12AA
	DW	0x17AB, 0x1A3D, 0x1F45, 0x2449, 0x2447, 0x2446, 0x21C9, 0x27CC, 0x2DEB, 0x27DC, 0x33BD, 0x2145, 0x112D, 0x1A24, 0x1A3A, 0x1CC3
	DW	0x2148, 0x24C4, 0x24C8, 0x20C7, 0x26CB, 0x2AE2, 0x2E54, 0x304E, 0x1EC2, 0x1826, 0x16A8, 0x1635, 0x1C3F, 0x2146, 0x2447, 0x2348
	DW	0x2244, 0x25C6, 0x2A63, 0x29D5, 0x32C5, 0x1FCB, 0x1429, 0x1B24, 0x15BB, 0x1B3A, 0x2246, 0x2249, 0x2444, 0x2244, 0x234C, 0x2554
	DW	0x2F5B, 0x2ADD, 0x26BC, 0x2032, 0x11B0, 0x162A, 0x1CBA, 0x1F48, 0x2449, 0x2649, 0x2547, 0x24CE, 0x2656, 0x31D7, 0x2AE5, 0x2443
	DW	0x252D, 0x1836, 0x14B5, 0x1D38, 0x20C5, 0x2449, 0x24CC, 0x2444, 0x23CD, 0x23D1, 0x2D5B, 0x2DDC, 0x2D47, 0x21C0, 0x15AD, 0x19A9
	DW	0x193D, 0x1CC3, 0x2547, 0x25CC, 0x24C9, 0x234C, 0x25CB, 0x2C5E, 0x2A58, 0x2F44, 0x20C5, 0x162C, 0x1B27, 0x193C, 0x1AC0, 0x23C3
	DW	0x244B, 0x22C8, 0x23C5, 0x25CA, 0x28D9, 0x2CD5, 0x2DD0, 0x2043, 0x1AAA, 0x18AB, 0x1636, 0x1BBB, 0x2146, 0x2349, 0x23C7, 0x22C4
	DW	0x24C8, 0x26D7, 0x2E4F, 0x2E56, 0x1EC7, 0x1E28, 0x1931, 0x13B5, 0x1DB7, 0x20C8, 0x2248, 0x2645, 0x2347, 0x2347, 0x2751, 0x2BDC
	DW	0x29D9, 0x2740, 0x21B4, 0x1634, 0x162F, 0x1DB7, 0x1F47, 0x2347, 0x25CA, 0x22C9, 0x2447, 0x26D1, 0x2ADB, 0x2AD7, 0x2AC4, 0x213D
	DW	0x1732, 0x192F, 0x1BBB, 0x1DC3, 0x2446, 0x254C, 0x22C9, 0x2443, 0x27CC, 0x26DD, 0x2B51, 0x2E49, 0x1FC5, 0x192F, 0x1AAC, 0x19B9
	DW	0x1BC0, 0x21C6, 0x23C7, 0x24C5, 0x22C7, 0x23CB, 0x26D1, 0x2CD2, 0x28D4, 0x213F, 0x1F2B, 0x1833, 0x1537, 0x1D39, 0x21C6, 0x22C8
	DW	0x2444, 0x2246, 0x22C9, 0x25CD, 0x2A54, 0x2851, 0x253E, 0x1EB4, 0x16B2, 0x17B0, 0x1CB8, 0x1EC4, 0x2245, 0x24C3, 0x2248, 0x21C9
	DW	0x264C, 0x2956, 0x2950, 0x27C2, 0x1EBA, 0x18AF, 0x19B1, 0x1A3B, 0x1EC1, 0x2348, 0x23C8, 0x2346, 0x2447, 0x25CE, 0x27D7, 0x2BD1
	DW	0x2ACB, 0x2142, 0x1BB3, 0x1B32, 0x1B3C, 0x1E43, 0x2347, 0x2549, 0x2446, 0x2448, 0x244F, 0x26D1, 0x2CD2, 0x2954, 0x22C1, 0x2033
	DW	0x1A36, 0x1938, 0x1EBE, 0x21C8, 0x2449, 0x2546, 0x22C8, 0x2348, 0x264A, 0x2853, 0x28D0, 0x2747, 0x203E, 0x1AB3, 0x1B33, 0x1BBC
	DW	0x1E42, 0x2346, 0x23C8, 0x2243, 0x2344, 0x234B, 0x254E, 0x294E, 0x25CD, 0x21BC, 0x1F34, 0x18B7, 0x19B6, 0x1EBC, 0x20C5, 0x2247
	DW	0x22C2, 0x2143, 0x21C5, 0x23CA, 0x264E, 0x284A, 0x2547, 0x1EBC, 0x1C33, 0x1B36, 0x1BBC, 0x1F41, 0x22C5, 0x23C7, 0x2243, 0x2242
	DW	0x2249, 0x23CB, 0x274C, 0x26CB, 0x2443, 0x203D, 0x1D3B, 0x1DBB, 0x1F40, 0x2145, 0x2346, 0x2447, 0x2243, 0x2243, 0x234A, 0x24CC
	DW	0x27CB, 0x2649, 0x2344, 0x203E, 0x1EBD, 0x1F3F, 0x2043, 0x2245, 0x23C6, 0x23C6, 0x2244, 0x21C3, 0x23C7, 0x244C, 0x25C9, 0x25C7
	DW	0x22C5, 0x20C1, 0x203F, 0x20C1, 0x20C3, 0x21C4, 0x22C4, 0x22C5, 0x21C4, 0x2243, 0x22C8, 0x2347, 0x25C7, 0x23CA, 0x2243, 0x2341
	DW	0x20C3, 0x2041, 0x2140, 0x20C1, 0x2142, 0x2144, 0x21C2, 0x21C3, 0x2142, 0x2243, 0x22C6, 0x21C6, 0x23C2, 0x2345, 0x20C4, 0x2140
	DW	0x2141, 0x20C1, 0x2142, 0x2144, 0x21C3, 0x2246, 0x2340
SMP4	DW	0x2142, 0x2142, 0x20C1, 0x20C1, 0x2142, 0x20C1, 0x2041, 0x20C2, 0x21C3, 0x21C3, 0x2142, 0x2142, 0x20C1, 0x20C2, 0x21C3, 0x21C2
	DW	0x20C1, 0x2142, 0x20C1, 0x1FC0, 0x20C3, 0x22C5, 0x21C2, 0x2143, 0x2246, 0x23C8, 0x2448, 0x22C3, 0x2141, 0x2041, 0x2040, 0x1FBC
	DW	0x1DBD, 0x1FC3, 0x2344, 0x2142, 0x21C7, 0x27D4, 0x2A51, 0x2544, 0x203E, 0x1E3C, 0x1EBF, 0x2145, 0x22C3, 0x1FBA, 0x1CBC, 0x1F40
	DW	0x20C0, 0x2148, 0x295A, 0x2ED7, 0x25BC, 0x18AC, 0x17B6, 0x1F45, 0x24CA, 0x23C2, 0x1E38, 0x1B37, 0x1CBB, 0x1DBD, 0x20CB, 0x2CE4
	DW	0x32DC, 0x2431, 0x111F, 0x1334, 0x214B, 0x274C, 0x23C0, 0x1CB5, 0x19B3, 0x1B38, 0x1CBD, 0x22D3, 0x326E, 0x3557, 0x1DA0, 0x0A18
	DW	0x14BC, 0x25D1, 0x284B, 0x223D, 0x1BB4, 0x19B4, 0x1BB8, 0x1D3D, 0x245A, 0x35F2, 0x34CF, 0x1818, 0x089B, 0x17C3, 0x2854, 0x28CA
	DW	0x21BC, 0x1BB4, 0x1A34, 0x1B36, 0x1CC1, 0x27E3, 0x39F4, 0x31C5, 0x1290, 0x081F, 0x1B4B, 0x2B57, 0x2949, 0x1FB8, 0x1A34, 0x1AB6
	DW	0x1BB7, 0x1DC5, 0x2CEE, 0x3D73, 0x2CB6, 0x0C0C, 0x0A29, 0x20D2, 0x2C56, 0x27C6, 0x1EB7, 0x1A33, 0x19B5, 0x1B39, 0x204E, 0x3175
	DW	0x3CEA, 0x25A8, 0x078B, 0x0CB2, 0x24D7, 0x2D54, 0x2540, 0x1C34, 0x1933, 0x1A36, 0x1B39, 0x20D3, 0x34F8, 0x3B60, 0x1F1D, 0x058F
	DW	0x113C, 0x2859, 0x2C51, 0x23BE, 0x1BB4, 0x19B4, 0x1A35, 0x1B3B, 0x23DB, 0x387B, 0x38D5, 0x1812, 0x0391, 0x1544, 0x2B5C, 0x2BCD
	DW	0x213A, 0x1AB3, 0x1934, 0x1AB6, 0x1D40, 0x2865, 0x3B79, 0x3448, 0x128E, 0x061C, 0x1BCF, 0x2E5D, 0x2ACA, 0x2039, 0x1AB4, 0x1AB6
	DW	0x1C39, 0x1EC7, 0x2CEE, 0x3E76, 0x2F3A, 0x0D8B, 0x08A7, 0x20D5, 0x2F5B, 0x2947, 0x1F37, 0x1A33, 0x1B38, 0x1DBD, 0x20CE, 0x31F7
	DW	0x3FF1, 0x282A, 0x0708, 0x0C34, 0x275E, 0x2FD7, 0x25C1, 0x1D36, 0x19B3, 0x1B38, 0x1D3F, 0x2357, 0x367C, 0x3CE2, 0x1E9A, 0x038C
	DW	0x11C1, 0x2B5F, 0x2DD0, 0x223C, 0x1BB5, 0x1A35, 0x1B37, 0x1CBF, 0x25DF, 0x397C, 0x3956, 0x1893, 0x0412, 0x15C6, 0x2CDE, 0x2CCD
	DW	0x20B8, 0x19B2, 0x19B6, 0x1C39, 0x1D40, 0x2866, 0x3D7E, 0x35C7, 0x1008, 0x039C, 0x1CD2, 0x2F5D, 0x29C8, 0x1F37, 0x1A32, 0x1935
	DW	0x1C3B, 0x1FC8, 0x2DEF, 0x3EF7, 0x2F38, 0x0B86, 0x0727, 0x22DA, 0x315C, 0x2844, 0x1DB6, 0x1A33, 0x1AB7, 0x1D3D, 0x21CF, 0x32F7
	DW	0x3FF1, 0x292C, 0x0787, 0x0BB3, 0x27E0, 0x315A, 0x26C1, 0x1CB4, 0x19B4, 0x1BB9, 0x1DBF, 0x23D8, 0x36FD, 0x3E66, 0x209D, 0x040B
	DW	0x10BF, 0x2BE2, 0x2FD4, 0x23BC, 0x1B33, 0x19B5, 0x1BBA, 0x1E41, 0x25DD, 0x38FC, 0x3ADB, 0x1B16, 0x0390, 0x14C6, 0x2D61, 0x2DD0
	DW	0x223A, 0x1AB2, 0x1935, 0x1CBB, 0x1F43, 0x27E3, 0x3AFC, 0x37D0, 0x150E, 0x0396, 0x194E, 0x2F5F, 0x2BCA, 0x1FB8, 0x19B2, 0x19B5
	DW	0x1C3A, 0x1F45, 0x29E6, 0x3B79, 0x3448, 0x128D, 0x051C, 0x1C52, 0x305F, 0x2B49, 0x1F38, 0x1AB4, 0x1AB7, 0x1CBB, 0x2049, 0x2C6B
	DW	0x3C76, 0x3142, 0x108D, 0x0722, 0x1F56, 0x30DF, 0x2A48, 0x1EB6, 0x1A33, 0x1AB8, 0x1D3D, 0x214C, 0x2EF0, 0x3DF5, 0x2E39, 0x0D0B
	DW	0x092B, 0x235B, 0x30DC, 0x2844, 0x1DB5, 0x19B3, 0x1B38, 0x1DBE, 0x21CF, 0x30F2, 0x3CEE, 0x2930, 0x0A8B, 0x0BB1, 0x255B, 0x2FD8
	DW	0x2642, 0x1CB4, 0x1932, 0x1AB8, 0x1E3F, 0x2250, 0x3172, 0x3BE9, 0x25A9, 0x080C, 0x0DB6, 0x275C, 0x2E54, 0x243E, 0x1C34, 0x19B3
	DW	0x1A37, 0x1CBE, 0x2253, 0x32F3, 0x3AE4, 0x2224, 0x070D, 0x0F39, 0x285C, 0x2E53, 0x23BD, 0x1B33, 0x18B2, 0x1AB8, 0x1E40, 0x2457
	DW	0x3474, 0x395E, 0x1FA1, 0x0792, 0x12BF, 0x29DD, 0x2D51, 0x233D, 0x1BB4, 0x19B5, 0x1B39, 0x1E41, 0x255A, 0x3573, 0x37DA, 0x1E22
	DW	0x0996, 0x1541, 0x2A5D, 0x2DD2, 0x23BD, 0x1BB5, 0x1A37, 0x1D3C, 0x1FC4, 0x26DD, 0x36F4, 0x3757, 0x1C1F, 0x0999, 0x17C6, 0x2B5C
	DW	0x2C4E, 0x22BD, 0x1CB6, 0x1A35, 0x1C3C, 0x1FC5, 0x275C, 0x3570, 0x3555, 0x1CA0, 0x0A9A, 0x1744, 0x2A5B, 0x2BCE, 0x21BC, 0x1BB5
	DW	0x1AB6, 0x1C3A, 0x1EC3, 0x265B, 0x34EF, 0x3453, 0x1BA1, 0x0B1B, 0x1742, 0x2959, 0x2B4D, 0x223C, 0x1B34, 0x19B6, 0x1C3B, 0x1EC1
	DW	0x2558, 0x336E, 0x34D5, 0x1D22, 0x0B1B, 0x16C1, 0x28D8, 0x2B4E, 0x223C, 0x1B33, 0x19B6, 0x1C3B, 0x1EC1, 0x2557, 0x32ED, 0x3455
	DW	0x1D23, 0x0B9C, 0x16C1, 0x28D8, 0x2B4F, 0x22BD, 0x1BB4, 0x1A37, 0x1D3C, 0x1F42, 0x24D7, 0x32ED, 0x34D7, 0x1EA7, 0x0D9E, 0x16C0
	DW	0x27D7, 0x2B50, 0x243F, 0x1C35, 0x1AB8, 0x1DBD, 0x1F41, 0x2455, 0x326C, 0x3559, 0x2028, 0x0D9C, 0x153D, 0x26D5, 0x2B51, 0x243F
	DW	0x1C34, 0x1A37, 0x1DBD, 0x1F40, 0x22D1, 0x2FEA, 0x34DB, 0x21AC, 0x0E9C, 0x143A, 0x24D3, 0x2AD0, 0x24C0, 0x1C34, 0x1935, 0x1D3D
	DW	0x1F3E, 0x214D, 0x2E67, 0x34DD, 0x23AF, 0x0F1B, 0x12B6, 0x2351, 0x2A50, 0x24C1, 0x1CB5, 0x19B6, 0x1D3C, 0x1E3D, 0x1FC8, 0x2BE3
	DW	0x34E2, 0x2736, 0x121C, 0x1131, 0x214E, 0x2A52, 0x26C4, 0x1E36, 0x1A36, 0x1D3D, 0x1EBD, 0x1EC3, 0x2960, 0x34E7, 0x2C41, 0x1620
	DW	0x10AD, 0x1ECB, 0x2A54, 0x2849, 0x203A, 0x1C38, 0x1DBE, 0x1F3C, 0x1E3F, 0x25DA, 0x336A, 0x30CE, 0x1C28, 0x10A7, 0x1AC3, 0x27D4
	DW	0x294C, 0x223C, 0x1CB9, 0x1DBD, 0x1EBB, 0x1CBA, 0x21D1, 0x2FE7, 0x32D7, 0x21B2, 0x12A3, 0x15B7, 0x22CF, 0x294F, 0x243F, 0x1C37
	DW	0x1C3C, 0x1F3B, 0x1BB5, 0x1D45, 0x2B63, 0x33E0, 0x27BC, 0x16A5, 0x13B0, 0x1EC9, 0x2851, 0x26C6, 0x1FBA, 0x1CBA, 0x1E3C, 0x1CB6
	DW	0x1B3D, 0x2559, 0x31E4, 0x2DCA, 0x1BAA, 0x1229, 0x1A40, 0x2550, 0x284B, 0x223E, 0x1DBA, 0x1DBC, 0x1DB7, 0x1B39, 0x20CE, 0x2E63
	DW	0x3158, 0x23B7, 0x1629, 0x1738, 0x214B, 0x2850, 0x2646, 0x203C, 0x1DBC, 0x1E3B, 0x1CB8, 0x1DC4, 0x285C, 0x30DE, 0x2A46, 0x1CB2
	DW	0x18B4, 0x1DC2, 0x244D, 0x274D, 0x2442, 0x1F3C, 0x1DBD, 0x1EBB, 0x1D3D, 0x21CD, 0x2C5D, 0x2E54, 0x243E, 0x1BB5, 0x1B3B, 0x1FC5
	DW	0x24CC, 0x26C9, 0x21BD, 0x1D3A, 0x1E3E, 0x1F3C, 0x1E3F, 0x234F, 0x2BD9, 0x2A4B, 0x213B, 0x1C39, 0x1DBE, 0x20C5, 0x244A, 0x24C5
	DW	0x1FBB, 0x1CBA, 0x1EBE, 0x1FBE, 0x1F40, 0x234C, 0x2953, 0x27C8, 0x203C, 0x1DBC, 0x1F40, 0x20C3, 0x22C6, 0x2343, 0x1FBB, 0x1CBB
	DW	0x1FC1, 0x2141, 0x1FBF, 0x2147, 0x26D0, 0x2749, 0x2241, 0x2041, 0x2141, 0x20C1, 0x21C6, 0x23C5, 0x20BE, 0x1E3D, 0x20C4, 0x2344
	DW	0x2140, 0x2043, 0x244D, 0x284F, 0x2648, 0x22C2, 0x2141, 0x20C2, 0x2245, 0x23C7, 0x2241, 0x1FBF, 0x20C4, 0x2346, 0x21C1, 0x2041
	DW	0x2249, 0x26CF, 0x26CA, 0x2344, 0x21C3, 0x2244, 0x2244, 0x21C3, 0x21C3, 0x2141, 0x20C2, 0x21C3, 0x21C2, 0x20C2, 0x21C4, 0x22C6
	DW	0x23C8, 0x24C8, 0x23C5, 0x21C2, 0x20C1, 0x2143, 0x21C3, 0x2141, 0x20C1, 0x20C2, 0x21C4, 0x2243, 0x21C2, 0x2143, 0x2246, 0x2448
	DW	0x23C5, 0x21C2, 0x2142, 0x2142, 0x20C1, 0x2142, 0x2142, 0x20C0
SMP5	DW	0x21C3, 0x21C3, 0x21C3, 0x21C2, 0x21C3, 0x2142, 0x2142, 0x2142, 0x2142, 0x21C3, 0x2143, 0x21C3, 0x2244, 0x21C3, 0x21C3, 0x21C3
	DW	0x21C2, 0x2142, 0x2142, 0x2142, 0x2142, 0x21C4, 0x2244, 0x22C5, 0x22C5, 0x2346, 0x2345, 0x2242, 0x2141, 0x20C0, 0x1FBF, 0x1FBF
	DW	0x1FC0, 0x20C4, 0x2347, 0x2448, 0x24CB, 0x26CF, 0x27CC, 0x24C4, 0x1FB9, 0x1AB3, 0x1ABA, 0x1FC1, 0x20BE, 0x1EBC, 0x1F41, 0x22C9
	DW	0x27D7, 0x2FE6, 0x30CF, 0x1A23, 0x11B2, 0x2352, 0x29CD, 0x2237, 0x15A5, 0x13B2, 0x204A, 0x2649, 0x21C0, 0x214D, 0x2DE3, 0x304C
	DW	0x1AA9, 0x16BA, 0x23CD, 0x25C7, 0x2036, 0x1627, 0x15B6, 0x20C5, 0x22C4, 0x21C5, 0x25D7, 0x3062, 0x29B7, 0x12A6, 0x1A47, 0x28D1
	DW	0x284E, 0x1EA3, 0x0A9A, 0x1847, 0x26C6, 0x1F3B, 0x1E3E, 0x224E, 0x2DE3, 0x3049, 0x1620, 0x13BA, 0x26D4, 0x294E, 0x212E, 0x0E18
	DW	0x133B, 0x2447, 0x20BC, 0x1E3E, 0x21CD, 0x2C61, 0x2FCD, 0x17A1, 0x13BA, 0x26D5, 0x29D1, 0x2531, 0x0B90, 0x10BE, 0x27CB, 0x1FB9
	DW	0x1CBC, 0x214C, 0x2BE1, 0x31D7, 0x1DA4, 0x1233, 0x2455, 0x2AD4, 0x27BC, 0x1011, 0x0D36, 0x264D, 0x21BB, 0x1D3F, 0x2149, 0x295B
	DW	0x31E2, 0x262E, 0x112B, 0x20D4, 0x2C54, 0x2ACA, 0x1692, 0x092A, 0x2452, 0x233A, 0x1CBE, 0x21C7, 0x2758, 0x30E3, 0x2C3C, 0x12A7
	DW	0x1C4D, 0x2C57, 0x2B51, 0x1D9D, 0x069B, 0x1E50, 0x26C0, 0x1C3B, 0x2042, 0x2452, 0x2E66, 0x324D, 0x1621, 0x15C3, 0x2AD8, 0x2B57
	DW	0x26AB, 0x050B, 0x15CB, 0x29C5, 0x1C3A, 0x1FC0, 0x204A, 0x2BE3, 0x345D, 0x1EA3, 0x11B5, 0x2657, 0x2BD7, 0x293B, 0x0D8C, 0x0E3C
	DW	0x26C8, 0x1F39, 0x1F41, 0x2045, 0x28DB, 0x32E4, 0x282F, 0x102A, 0x2155, 0x2CD7, 0x2C50, 0x190D, 0x0324, 0x2455, 0x253B, 0x1CBE
	DW	0x1EBE, 0x2456, 0x326B, 0x30C6, 0x1321, 0x18CA, 0x2C5B, 0x2DD8, 0x229F, 0x0394, 0x1BD0, 0x27C0, 0x1D3E, 0x1F3C, 0x20D0, 0x2F68
	DW	0x3459, 0x1BA0, 0x133D, 0x29DC, 0x2CDA, 0x2B3E, 0x0B01, 0x0BC1, 0x2B4F, 0x1F38, 0x1F3E, 0x1DC2, 0x2963, 0x3665, 0x27AE, 0x102D
	DW	0x2253, 0x2CDB, 0x2DCF, 0x1609, 0x05AC, 0x25D0, 0x2139, 0x1E3F, 0x1D3B, 0x23D9, 0x3266, 0x2F46, 0x13A2, 0x1948, 0x2B58, 0x2C58
	DW	0x2423, 0x020C, 0x194D, 0x26BF, 0x1C3D, 0x1F38, 0x1D4B, 0x2EE8, 0x32D7, 0x1CA2, 0x13BA, 0x25D5, 0x2CDB, 0x2B3D, 0x0B04, 0x0CBD
	DW	0x26C6, 0x1E3B, 0x1FBB, 0x1B3E, 0x2961, 0x33E2, 0x2A34, 0x10AA, 0x1F4E, 0x2C5A, 0x2DD4, 0x1C13, 0x021D, 0x204D, 0x233E, 0x1FC1
	DW	0x1D36, 0x2158, 0x32E6, 0x2F4E, 0x19A6, 0x1841, 0x27D9, 0x2EDB, 0x25A9, 0x0713, 0x16C4, 0x23C0, 0x2043, 0x1F37, 0x1DCC, 0x2EE4
	DW	0x31DC, 0x2227, 0x13B7, 0x24D4, 0x2C5B, 0x2D43, 0x0F8A, 0x0AB3, 0x2344, 0x20C4, 0x22BA, 0x193D, 0x2A61, 0x315F, 0x2B3D, 0x13AA
	DW	0x1D4B, 0x2AD9, 0x2D52, 0x1A15, 0x0724, 0x1DC4, 0x2041, 0x22C1, 0x1AB6, 0x23DB, 0x3162, 0x2ECA, 0x1626, 0x1943, 0x28D6, 0x2CDA
	DW	0x24A8, 0x0894, 0x153E, 0x2142, 0x23C7, 0x1E33, 0x1DCF, 0x2EE1, 0x30D8, 0x21AB, 0x1538, 0x24D2, 0x2BDB, 0x2ABB, 0x0D12, 0x1237
	DW	0x1F40, 0x234B, 0x2235, 0x1C4A, 0x2CDC, 0x2F5E, 0x29B8, 0x13B1, 0x21CF, 0x2956, 0x2D4F, 0x1797, 0x0BAA, 0x1D3F, 0x21CC, 0x25BF
	DW	0x1ABE, 0x28DC, 0x2F5F, 0x2D46, 0x182E, 0x1D48, 0x27D4, 0x2DD8, 0x1E9D, 0x0C28, 0x1A39, 0x20CA, 0x2744, 0x1CBB, 0x24D4, 0x2C5C
	DW	0x2FD5, 0x1F2D, 0x19C2, 0x24CC, 0x2A5A, 0x2630, 0x0FA0, 0x1633, 0x1CC5, 0x274A, 0x203B, 0x21D1, 0x2B58, 0x2FDA, 0x22B2, 0x19BD
	DW	0x2248, 0x285A, 0x2B3E, 0x111D, 0x142F, 0x19C1, 0x274E, 0x22BD, 0x1F49, 0x28D5, 0x2E5E, 0x273B, 0x19B8, 0x1F43, 0x24D4, 0x2BCA
	DW	0x18A0, 0x1129, 0x173A, 0x254F, 0x25C4, 0x2044, 0x25D2, 0x2C5C, 0x2A44, 0x1CBA, 0x1E3E, 0x22CD, 0x28CC, 0x1EB0, 0x14A9, 0x16B6
	DW	0x214A, 0x2649, 0x22C2, 0x23D1, 0x2CDB, 0x2B4B, 0x203A, 0x1C3C, 0x21CA, 0x27CE, 0x2339, 0x16A9, 0x1633, 0x1EC7, 0x25CC, 0x24C4
	DW	0x234F, 0x2AD8, 0x2C4E, 0x21BB, 0x1C3A, 0x1F45, 0x254D, 0x25C1, 0x1928, 0x14AE, 0x1ABF, 0x24CD, 0x25C5, 0x22CB, 0x27D2, 0x29CE
	DW	0x2441, 0x1C38, 0x1DBD, 0x2146, 0x23C3, 0x1CB0, 0x162D, 0x19BA, 0x2047, 0x2547, 0x234A, 0x2956, 0x2A4B, 0x223C, 0x1AB5, 0x1D40
	DW	0x2247, 0x24C6, 0x1D2D, 0x14AB, 0x1736, 0x2048, 0x25C8, 0x23C8, 0x2650, 0x28CE, 0x2542, 0x1DB9, 0x1D3B, 0x1FC3, 0x23C5, 0x1F37
	DW	0x18AD, 0x17B5, 0x1E40, 0x234A, 0x2446, 0x25D2, 0x2AD0, 0x25C9, 0x1F36, 0x1C3A, 0x1E40, 0x234A, 0x22BD, 0x1B30, 0x162F, 0x1B3C
	DW	0x2149, 0x25C9, 0x24CE, 0x2A54, 0x26C9, 0x233C, 0x1BB9, 0x1DBD, 0x2149, 0x2442, 0x1EB7, 0x18B0, 0x1A39, 0x1E44, 0x254A, 0x244A
	DW	0x27D4, 0x29CB, 0x24C6, 0x1CB6, 0x1D3A, 0x1DC1, 0x2446, 0x1FBC, 0x1CB2, 0x18B5, 0x1C3C, 0x2248, 0x24CA, 0x2754, 0x2C50, 0x23C8
	DW	0x1F33, 0x1B39, 0x1CBD, 0x2349, 0x223F, 0x1E37, 0x1932, 0x1AB8, 0x1EC3, 0x23C9, 0x254E, 0x2955, 0x29C6, 0x22C0, 0x19B3, 0x1BB8
	DW	0x1EC3, 0x23C4, 0x203E, 0x1CB4, 0x19B5, 0x1C3C, 0x20C6, 0x244A, 0x27D3, 0x2B51, 0x2447, 0x2036, 0x1AB7, 0x1C3D, 0x2145, 0x2242
	DW	0x203B, 0x1B36, 0x1B39, 0x1DC0, 0x2246, 0x254E, 0x2954, 0x2ACE, 0x2446, 0x1E35, 0x1C38, 0x1CBE, 0x2144, 0x2142, 0x20BA, 0x1CB9
	DW	0x1CB9, 0x1EC2, 0x2247, 0x26D0, 0x29D6, 0x2A4C, 0x24C2, 0x1CB8, 0x1C37, 0x1D3E, 0x2041, 0x20C2, 0x1F3C, 0x1E3A, 0x1CBB, 0x1F40
	DW	0x21C7, 0x254D, 0x2954, 0x27CC, 0x24C2, 0x1EBC, 0x1C37, 0x1D3B, 0x1DBC, 0x1EBC, 0x1D3A, 0x1D3A, 0x1E3E, 0x2044, 0x254F, 0x29D3
	DW	0x28CE, 0x2443, 0x1FBB, 0x1CB9, 0x1DBD, 0x1FC0, 0x20C1, 0x1F3C, 0x1DB9, 0x1C38, 0x1CBA, 0x1DBE, 0x20C4, 0x23C9, 0x25CC, 0x26CD
	DW	0x2548, 0x22C1, 0x1F3A, 0x1C37, 0x1BB8, 0x1CBB, 0x1EBF, 0x2041, 0x2143, 0x22C7, 0x25CE, 0x274E, 0x26CA, 0x23C5, 0x2141, 0x20C0
	DW	0x20C1, 0x2040, 0x1FBE, 0x1EBC, 0x1E3C, 0x1E3D, 0x1EBE, 0x2041, 0x20C3, 0x2246, 0x23C8, 0x24CA, 0x254A, 0x2548, 0x22C3, 0x20BE
	DW	0x1E3B, 0x1DBB, 0x1E3D, 0x1F3F, 0x2042, 0x21C3, 0x21C4, 0x2349, 0x254A, 0x25CC, 0x25C9, 0x2446, 0x2242, 0x203E, 0x1EBC, 0x1DBB
	DW	0x1E3C, 0x1EBE, 0x1FC0, 0x2040, 0x2040, 0x20C2, 0x21C4, 0x2347, 0x23C7, 0x23C7, 0x2345, 0x2242, 0x20BF, 0x1F3D, 0x1EBD, 0x1EBE
	DW	0x1FBF, 0x1FBF, 0x1FC0, 0x2041, 0x21C4, 0x22C6, 0x23C7, 0x23C7, 0x23C6, 0x2243, 0x20C0, 0x1FBE, 0x1EBE, 0x1F3E, 0x1F3F, 0x1FBF
	DW	0x1FBF, 0x2041, 0x2143, 0x21C5, 0x2347, 0x23C7, 0x2447, 0x2345, 0x2243, 0x2141, 0x2040, 0x1FBF, 0x1F3E, 0x1F3E, 0x1F3F, 0x2041
	DW	0x20C1, 0x2142, 0x21C4, 0x22C6, 0x2346, 0x2345, 0x22C5, 0x22C5, 0x2244, 0x21C2, 0x20C1, 0x2040, 0x2040, 0x2040, 0x2040, 0x20C2
	DW	0x2142, 0x21C3, 0x21C4, 0x2243, 0x2244, 0x2244, 0x2243, 0x21C3, 0x2142, 0x20C1, 0x20C1, 0x2041, 0x2040, 0x20C1, 0x20C2, 0x2142
	DW	0x2142, 0x2143, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C2, 0x2142, 0x20C1, 0x20C1, 0x20C1, 0x2142, 0x20C1, 0x2142, 0x2143
	DW	0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C2, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2143, 0x21C3, 0x21C3
	DW	0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C2, 0x2142, 0x2142, 0x2142, 0x2143, 0x2143, 0x21C3, 0x21C3, 0x21C3
	DW	0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142
	DW	0x2142, 0x2142, 0x2141, 0x2141, 0x20C1, 0x20C1, 0x20C0
SMP6	DW	0x2244, 0x2245, 0x22C5, 0x2345, 0x22C5, 0x2345, 0x22C5, 0x2244, 0x2244, 0x21C2, 0x2142, 0x2142, 0x21C5, 0x23C9, 0x25CE, 0x2852
	DW	0x2AD8, 0x2BD2, 0x284B, 0x21BD, 0x1BB4, 0x182E, 0x1832, 0x1B3B, 0x2149, 0x26D3, 0x2D5E, 0x326C, 0x38EE, 0x2F56, 0x273B, 0x16A8
	DW	0x12A4, 0x11AC, 0x1BB9, 0x1F44, 0x23C7, 0x23CB, 0x25C7, 0x2651, 0x2BE3, 0x34D4, 0x29D3, 0x1E31, 0x14A7, 0x131C, 0x1536, 0x19BB
	DW	0x2147, 0x2444, 0x28D1, 0x2760, 0x3970, 0x29D0, 0x2C36, 0x1027, 0x1523, 0x0DB0, 0x2135, 0x1C46, 0x20B6, 0x1B44, 0x20B7, 0x23D9
	DW	0x31EE, 0x38E2, 0x2E4B, 0x1AAC, 0x101B, 0x0E1F, 0x1635, 0x1D43, 0x2140, 0x203E, 0x203C, 0x20CB, 0x2CEC, 0x39E3, 0x2DDD, 0x1F29
	DW	0x1523, 0x0E1B, 0x163A, 0x1B3F, 0x23BF, 0x1C3B, 0x1F3B, 0x1B46, 0x2859, 0x36FB, 0x35DB, 0x2EC6, 0x14A2, 0x111E, 0x0D2E, 0x1FBA
	DW	0x204B, 0x2239, 0x1C40, 0x1DB1, 0x2251, 0x2BE9, 0x3F75, 0x2EDE, 0x26AC, 0x1121, 0x0F9D, 0x1540, 0x1FBE, 0x2646, 0x1C36, 0x1CB7
	DW	0x1840, 0x2650, 0x337F, 0x3CE0, 0x3255, 0x16A1, 0x121B, 0x0B26, 0x1F3F, 0x1ECF, 0x2537, 0x1B38, 0x19AA, 0x1CC5, 0x2154, 0x3A7E
	DW	0x3761, 0x3446, 0x10A7, 0x118F, 0x0CB1, 0x1EB9, 0x2251, 0x1FB2, 0x1D36, 0x152D, 0x1F3F, 0x205E, 0x3B79, 0x3665, 0x323B, 0x12AD
	DW	0x0D11, 0x10B3, 0x1D3E, 0x2750, 0x1DB9, 0x1E2C, 0x1533, 0x1CB9, 0x22DE, 0x38F9, 0x3A66, 0x3146, 0x16AA, 0x0E95, 0x10AE, 0x1D45
	DW	0x25CF, 0x223C, 0x1D2F, 0x1730, 0x1ABC, 0x2155, 0x36FB, 0x3B69, 0x34D2, 0x18AD, 0x1396, 0x0DAC, 0x1C40, 0x2452, 0x243D, 0x1F37
	DW	0x17AF, 0x1AB9, 0x1ECA, 0x2FF2, 0x3C6D, 0x34E2, 0x20B0, 0x181E, 0x0BA3, 0x1839, 0x204A, 0x25C1, 0x1F3D, 0x1AB0, 0x1AB9, 0x1CC1
	DW	0x2761, 0x3AEB, 0x316B, 0x28B6, 0x1CA9, 0x0C21, 0x1631, 0x1C47, 0x2440, 0x213F, 0x1BB3, 0x19B8, 0x1B3C, 0x234C, 0x2F75, 0x34D9
	DW	0x35D1, 0x1937, 0x159D, 0x10AD, 0x1C3A, 0x21C9, 0x203F, 0x2036, 0x1936, 0x1CB7, 0x1FC5, 0x26DA, 0x36F2, 0x2B67, 0x2F31, 0x1BB8
	DW	0x0F24, 0x1A38, 0x1D44, 0x2641, 0x1FC3, 0x1AB5, 0x1D39, 0x1D40, 0x23CA, 0x2965, 0x3663, 0x2EE2, 0x24B6, 0x1F33, 0x1332, 0x1D3A
	DW	0x1FC7, 0x2541, 0x1FC1, 0x1CB5, 0x1EBD, 0x1D44, 0x254A, 0x2A64, 0x38DD, 0x2F68, 0x213C, 0x252E, 0x15B9, 0x1B36, 0x20CD, 0x1F3F
	DW	0x26BC, 0x1C44, 0x1DB9, 0x20C6, 0x20C8, 0x2956, 0x2E65, 0x2CD8, 0x2BC5, 0x20BC, 0x19B0, 0x18B4, 0x1A35, 0x1CB9, 0x1DBE, 0x2043
	DW	0x23CC, 0x29DA, 0x34EA, 0x2BDF, 0x2D3A, 0x1F3F, 0x1531, 0x1CB6, 0x1F48, 0x28D0, 0x28D2, 0x23C3, 0x2031, 0x1832, 0x16B0, 0x1CBC
	DW	0x1FC7, 0x264C, 0x27D4, 0x28CF, 0x2951, 0x26CE, 0x2646, 0x213F, 0x1CB5, 0x1933, 0x19B5, 0x1D3D, 0x20C6, 0x244B, 0x27D1, 0x2CE2
	DW	0x305B, 0x2DD4, 0x23C4, 0x2137, 0x1C3C, 0x1D3D, 0x22C7, 0x244D, 0x2849, 0x2447, 0x1EBB, 0x1D33, 0x19B9, 0x1C3A, 0x2147, 0x244E
	DW	0x2A52, 0x28D4, 0x28CD, 0x25C8, 0x22C1, 0x1FBF, 0x1E3B, 0x1E3B, 0x1DBD, 0x1EBF, 0x1FC2, 0x21C4, 0x22C8, 0x254D, 0x29D8, 0x2CD6
	DW	0x2C52, 0x23C8, 0x2138, 0x1CB8, 0x1A36, 0x1CBA, 0x1CBC, 0x1F3A, 0x1EC0, 0x1EC0, 0x22C6, 0x2554, 0x2BD4, 0x2AD9, 0x2748, 0x25C0
	DW	0x1D3C, 0x1BB6, 0x1D3C, 0x1F3E, 0x21C7, 0x22C8, 0x2546, 0x21C3, 0x1E39, 0x1C36, 0x1B39, 0x1DBD, 0x1FC2, 0x22C6, 0x23C8, 0x2447
	DW	0x23C5, 0x2242, 0x20C0, 0x1F3F, 0x1F3D, 0x1FC2, 0x20C1, 0x22C4, 0x2246, 0x2345, 0x22C5, 0x21C3, 0x2243, 0x21C4, 0x22C5, 0x2346
	DW	0x22C6, 0x2244, 0x2242, 0x2144, 0x21C4, 0x22C4, 0x2346, 0x22C6, 0x22C5, 0x2345, 0x22C5, 0x2346, 0x2347, 0x23C6, 0x23C6, 0x22C5
	DW	0x21C3, 0x2243, 0x2143, 0x2243, 0x22C5, 0x22C5, 0x2345, 0x22C5, 0x22C4, 0x2346, 0x22C6, 0x2344, 0x22C4, 0x2143, 0x21C2, 0x2142
	DW	0x2142, 0x2143, 0x2142, 0x21C3, 0x21C4, 0x2245, 0x22C6, 0x2345, 0x2345, 0x2244, 0x21C3, 0x2142, 0x2141, 0x20C0, 0x2041, 0x2040
	DW	0x20C0, 0x2042, 0x21C2, 0x2245, 0x22C5, 0x2344, 0x2245, 0x2243, 0x2243, 0x2143, 0x2141, 0x20C2, 0x20C1, 0x2141, 0x20C2, 0x20C2
	DW	0x2143, 0x2243, 0x22C5, 0x2245, 0x22C5, 0x22C6, 0x2345, 0x22C5, 0x21C4, 0x2243, 0x21C3, 0x2142, 0x2142, 0x2143, 0x21C3, 0x21C4
	DW	0x2244, 0x22C5, 0x22C6, 0x22C6, 0x2345, 0x22C5, 0x22C5, 0x22C5, 0x22C5, 0x22C4, 0x21C3, 0x2142, 0x2142, 0x2143, 0x21C3, 0x21C4
	DW	0x21C4, 0x2244, 0x2244, 0x22C4, 0x2245, 0x22C4, 0x2244, 0x21C3, 0x2142, 0x2141, 0x20C1, 0x20C1, 0x20C1, 0x2141, 0x20C1, 0x20C2
	DW	0x2142, 0x21C2, 0x21C3, 0x21C2, 0x2142, 0x2142, 0x20C2, 0x20C1, 0x20C1, 0x20C0, 0x2040, 0x2040, 0x2040
SMP7	DW	0x2346, 0x2348, 0x2449, 0x2549, 0x2549, 0x2448, 0x2345, 0x22C3, 0x20C0, 0x1FBF, 0x1EBC, 0x1FBE, 0x1DBC, 0x1E45, 0x26D0, 0x2AD7
	DW	0x2BD6, 0x25C3, 0x1FBC, 0x1EBD, 0x2046, 0x23C4, 0x213E, 0x1F3E, 0x1CB4, 0x16B0, 0x1B39, 0x24D8, 0x30E4, 0x2F56, 0x273D, 0x18AF
	DW	0x1ABD, 0x21C8, 0x274C, 0x22BE, 0x1DBB, 0x1D36, 0x17A5, 0x14B3, 0x2461, 0x3262, 0x325B, 0x26B6, 0x12AB, 0x1A39, 0x214B, 0x29D2
	DW	0x223D, 0x1D39, 0x1CB6, 0x19AA, 0x112E, 0x1E5E, 0x3663, 0x31E0, 0x293F, 0x1222, 0x1ABC, 0x214A, 0x29D7, 0x25BB, 0x1C3A, 0x1CB8
	DW	0x1AAD, 0x11A8, 0x1A4F, 0x39E9, 0x31E2, 0x2A46, 0x1597, 0x163E, 0x214A, 0x28D7, 0x2A3E, 0x1A37, 0x1BBA, 0x1AB0, 0x1422, 0x16BD
	DW	0x35F3, 0x31E1, 0x2CCB, 0x1B97, 0x0EBB, 0x21C9, 0x2754, 0x2CC8, 0x19B3, 0x1BB9, 0x1BB1, 0x159F, 0x12B5, 0x297B, 0x3560, 0x2F4F
	DW	0x1FA4, 0x08AC, 0x2247, 0x2753, 0x2B54, 0x1E2F, 0x19B8, 0x1DB6, 0x1622, 0x10AF, 0x1FEC, 0x3C65, 0x31D7, 0x2336, 0x0C9A, 0x1E48
	DW	0x2652, 0x2AD7, 0x2635, 0x1938, 0x1DBA, 0x19AA, 0x11A4, 0x19CB, 0x3D73, 0x31DF, 0x2A43, 0x1896, 0x12C5, 0x264E, 0x2A55, 0x2B48
	DW	0x1A33, 0x1D3C, 0x1CB3, 0x13A1, 0x15B9, 0x2D7F, 0x35E3, 0x2F4F, 0x202C, 0x0CB3, 0x254C, 0x28D5, 0x29D3, 0x21B4, 0x1BBD, 0x1E3A
	DW	0x19AA, 0x1230, 0x1D59, 0x3C69, 0x30DC, 0x2741, 0x1A23, 0x19C8, 0x25D0, 0x2AD0, 0x27C8, 0x1D3A, 0x203B, 0x1DB6, 0x14A5, 0x1937
	DW	0x27EB, 0x31DC, 0x2C4C, 0x223E, 0x16B4, 0x22CB, 0x27D4, 0x274C, 0x25C1, 0x1F41, 0x1F3D, 0x1EB3, 0x172F, 0x1AB9, 0x2453, 0x2BD2
	DW	0x27CA, 0x2444, 0x1EBF, 0x2249, 0x274E, 0x264C, 0x24C7, 0x22C3, 0x2041, 0x1FBF, 0x1DB9, 0x1C39, 0x1DC0, 0x234B, 0x264E, 0x27CC
	DW	0x2445, 0x2246, 0x24CB, 0x274E, 0x26CB, 0x23C5, 0x2244, 0x2346, 0x2343, 0x1EB8, 0x1BB7, 0x1E41, 0x234B, 0x26CD, 0x2649, 0x2345
	DW	0x234A, 0x274E, 0x26CC, 0x25C8, 0x24CA, 0x25CB, 0x24C7, 0x2342, 0x1EBB, 0x1CBB, 0x2042, 0x2245, 0x2348, 0x2446, 0x2348, 0x2449
	DW	0x254A, 0x25CD, 0x264C, 0x25CA, 0x24C8, 0x2345, 0x21C1, 0x20C2, 0x203F, 0x1FBF, 0x2040, 0x1FC0, 0x20C2, 0x21C4, 0x2246, 0x23C7
	DW	0x2448, 0x24C9, 0x2447, 0x2344, 0x21C3, 0x2242, 0x21C2, 0x203E, 0x1E39, 0x1CBB, 0x1DBC, 0x1E3D, 0x1FC0, 0x2040, 0x2143, 0x22C6
	DW	0x2346, 0x23C6, 0x2346, 0x22C5, 0x2346, 0x2345, 0x21C2, 0x20C0, 0x1FBE, 0x1FBF, 0x1FBD, 0x1EBE, 0x2041, 0x21C4, 0x2347, 0x2448
	DW	0x24C9, 0x254A, 0x254B, 0x2549, 0x24C9, 0x24C8, 0x2447, 0x22C4, 0x203F, 0x1F3E, 0x1FC0, 0x2041, 0x2143, 0x21C4, 0x2245, 0x22C6
	DW	0x23C8, 0x2449, 0x254A, 0x24C9, 0x2447, 0x22C3, 0x2142, 0x1FBD, 0x1E3B, 0x1D3A, 0x1DBC, 0x1E3C, 0x1EBE, 0x1F3F, 0x20C2, 0x21C4
	DW	0x22C6, 0x2448, 0x2447, 0x2345, 0x22C5, 0x21C2, 0x20C0, 0x1F3C, 0x1DB9, 0x1CB9, 0x1C39, 0x1D3C, 0x1F3F, 0x2041, 0x2144, 0x22C6
	DW	0x23C8, 0x2449, 0x24C9, 0x2448, 0x2447, 0x2344, 0x21C1, 0x1F3D, 0x1D3A, 0x1CBA, 0x1DBC, 0x1EBF, 0x20C2, 0x21C3, 0x21C4, 0x2347
	DW	0x24CB, 0x264C, 0x264B, 0x2549, 0x2448, 0x2345, 0x213F, 0x1E3B, 0x1CBA, 0x1E3E, 0x2042, 0x21C4, 0x22C5, 0x22C5, 0x2348, 0x254C
	DW	0x26CE, 0x26CC, 0x2549, 0x2549, 0x2446, 0x21BF, 0x1EBA, 0x1D3B, 0x1F3F, 0x2144, 0x2346, 0x2344, 0x2244, 0x22C8, 0x254B, 0x264C
	DW	0x254A, 0x2447, 0x23C6, 0x2344, 0x203C, 0x1CB8, 0x1D3E, 0x20C5, 0x23C8, 0x24C7, 0x21C2, 0x2143, 0x2348, 0x254C, 0x25C8, 0x2344
	DW	0x2244, 0x21C1, 0x1FBB, 0x1C35, 0x1C3D, 0x2146, 0x254C, 0x2649, 0x21BF, 0x1F3F, 0x21C6, 0x24CC, 0x25C8, 0x22C2, 0x20C1, 0x203E
	DW	0x1DB7, 0x1AB7, 0x1E43, 0x24CD, 0x2851, 0x2645, 0x1FBD, 0x1FC2, 0x234B, 0x27CE, 0x25C6, 0x21C2, 0x20C1, 0x1FBA, 0x1B34, 0x1B3E
	DW	0x23CF, 0x2954, 0x29CD, 0x22BD, 0x1E40, 0x22C9, 0x2752, 0x294D, 0x2344, 0x21C1, 0x1FBC, 0x1C35, 0x1ABD, 0x2551, 0x2A55, 0x2AD1
	DW	0x23BD, 0x1E41, 0x234B, 0x27D4, 0x2ACF, 0x2445, 0x2244, 0x20BE, 0x1CB6, 0x1ABB, 0x2350, 0x2A55, 0x2AD0, 0x243F, 0x1DBF, 0x22CB
	DW	0x2854, 0x2B51, 0x24C4, 0x2244, 0x21BF, 0x1D37, 0x1AB7, 0x214D, 0x2A55, 0x29CF, 0x24BF, 0x1CBB, 0x21CB, 0x27D2, 0x2A51, 0x25C4
	DW	0x20C4, 0x2241, 0x1DB7, 0x1A33, 0x1EC8, 0x27D2, 0x29D0, 0x25C1, 0x1DBB, 0x2048, 0x26D2, 0x2A52, 0x2646, 0x2143, 0x21C2, 0x1EB9
	DW	0x1B33, 0x1C43, 0x26D2, 0x2950, 0x26C5, 0x1F3B, 0x1FC7, 0x26D1, 0x29D3, 0x27C9, 0x2242, 0x2242, 0x1FBA, 0x1B33, 0x1BC0, 0x24CE
	DW	0x28D1, 0x2747, 0x203D, 0x1FC6, 0x25D0, 0x2952, 0x27CA, 0x22C4, 0x22C4, 0x20BB, 0x1C34, 0x1ABC, 0x22CC, 0x27CF, 0x2749, 0x21BE
	DW	0x1FC4, 0x254E, 0x28D2, 0x284C, 0x23C4, 0x2245, 0x213D, 0x1CB5, 0x1939, 0x2149, 0x26CE, 0x274B, 0x223F, 0x1F42, 0x244C, 0x27D1
	DW	0x284D, 0x2444, 0x2244, 0x21BF, 0x1D36, 0x19B7, 0x1EC4, 0x24CB, 0x264B, 0x2342, 0x1FC1, 0x23CA, 0x26D0, 0x27CD, 0x24C6, 0x2244
	DW	0x2241, 0x1EB9, 0x1AB4, 0x1D40, 0x2348, 0x254A, 0x2445, 0x2142, 0x22CA, 0x264E, 0x274E, 0x2648, 0x2346, 0x22C3, 0x203B, 0x1BB5
	DW	0x1BBC, 0x2146, 0x244A, 0x24C7, 0x22C4, 0x2349, 0x264E, 0x27CE, 0x26CB, 0x2448, 0x23C6, 0x21BF, 0x1DB8, 0x1B39, 0x1F42, 0x22C7
	DW	0x23C8, 0x23C6, 0x2348, 0x25CD, 0x274E, 0x274D, 0x25C9, 0x2448, 0x2343, 0x1FBB, 0x1C38, 0x1D3D, 0x2042, 0x2245, 0x22C6, 0x2348
	DW	0x254B, 0x26CE, 0x274D, 0x264B, 0x2549, 0x2445, 0x213F, 0x1E3A, 0x1C38, 0x1D3C, 0x1EBF, 0x20C2, 0x2246, 0x23C9, 0x264D, 0x274D
	DW	0x26CC, 0x25CA, 0x2447, 0x2241, 0x1F3A, 0x1CB7, 0x1BB8, 0x1CBB, 0x1EBF, 0x20C3, 0x22C7, 0x24CB, 0x264D, 0x26CD, 0x264B, 0x2548
	DW	0x2344, 0x20BE, 0x1E3A, 0x1CB8, 0x1CBA, 0x1DBE, 0x1FC1, 0x21C5, 0x23C9, 0x25CD, 0x274E, 0x274D, 0x264B, 0x24C7, 0x22C2, 0x203D
	DW	0x1D39, 0x1CB9, 0x1D3C, 0x1F40, 0x2143, 0x22C8, 0x24CB, 0x26CE, 0x274E, 0x26CC, 0x25CA, 0x2446, 0x2241, 0x1F3D, 0x1D39, 0x1CBA
	DW	0x1E3D, 0x1FC1, 0x21C5, 0x2348, 0x254B, 0x264D, 0x264C, 0x25C9, 0x2447, 0x22C2, 0x203D, 0x1DB9, 0x1C38, 0x1CBB, 0x1EBE, 0x2042
	DW	0x21C5, 0x23C9, 0x254B, 0x264B, 0x25CA, 0x24C8, 0x2345, 0x2140, 0x1F3C, 0x1D38, 0x1C39, 0x1D3B, 0x1EBF, 0x2042, 0x2246, 0x23C9
	DW	0x254B, 0x25CA, 0x2549, 0x2447, 0x22C3, 0x20BF, 0x1E3A, 0x1CB8, 0x1CBA, 0x1DBD, 0x1FC0, 0x2144, 0x22C7, 0x24CB, 0x25CC, 0x25CB
	DW	0x2549, 0x2447, 0x22C3, 0x20BE, 0x1E3B, 0x1D3A, 0x1DBC, 0x1EBF, 0x2042, 0x2245, 0x23C9, 0x254B, 0x264C, 0x264B, 0x2549, 0x2446
	DW	0x2243, 0x203F, 0x1EBC, 0x1DBB, 0x1EBD, 0x1FC0, 0x2143, 0x22C6, 0x244A, 0x25CC, 0x264C, 0x264B, 0x2548, 0x23C6, 0x2242, 0x203F
	DW	0x1EBC, 0x1DBC, 0x1EBE, 0x1FC1, 0x2143, 0x22C6, 0x2449, 0x25CB, 0x264C, 0x25CA, 0x24C7, 0x2345, 0x21C2, 0x203E, 0x1EBC, 0x1DBC
	DW	0x1EBE, 0x1FC0, 0x20C2, 0x2245, 0x23C9, 0x254B, 0x25CB, 0x2549, 0x2447, 0x2345, 0x21C1, 0x203E, 0x1EBC, 0x1E3C, 0x1E3D, 0x1F3F
	DW	0x20C2, 0x2245, 0x23C8, 0x254B, 0x25CB, 0x25CA, 0x24C7, 0x2345, 0x2243, 0x20BF, 0x1F3D, 0x1E3C, 0x1EBD, 0x1F3F, 0x2042, 0x21C5
	DW	0x2348, 0x254B, 0x264C, 0x264B, 0x2549, 0x2447, 0x22C4, 0x21C1, 0x203E, 0x1EBD, 0x1EBE, 0x1FBF, 0x20C2, 0x21C4, 0x2347, 0x24CB
	DW	0x264C, 0x264C, 0x25CA, 0x24C8, 0x23C6, 0x2243, 0x20BF, 0x1F3E, 0x1EBD, 0x1F3F, 0x1FC0
SMP8	DW	0x20BF, 0x2144, 0x2243, 0x2349, 0x2448, 0x24CA, 0x2445, 0x2244, 0x1FBD, 0x1F3D, 0x1DBA, 0x1CB8, 0x1B38, 0x1EC1, 0x22C8, 0x264D
	DW	0x28DE, 0x34E1, 0x1FBE, 0x20A5, 0x12BC, 0x22C8, 0x26DA, 0x2BC0, 0x1BA9, 0x0E9E, 0x13BA, 0x2249, 0x2AD1, 0x233F, 0x1F3E, 0x1FC5
	DW	0x28D5, 0x2B56, 0x2843, 0x1AAD, 0x1428, 0x17B8, 0x20C6, 0x2447, 0x20BF, 0x20C6, 0x2862, 0x37EB, 0x26C5, 0x2125, 0x1034, 0x1F47
	DW	0x29E1, 0x30C6, 0x1C30, 0x0E19, 0x1439, 0x2148, 0x2AD3, 0x22C0, 0x21BF, 0x204A, 0x2A56, 0x2BD3, 0x2441, 0x1A2B, 0x162B, 0x1838
	DW	0x1F41, 0x21C4, 0x21C1, 0x22CD, 0x2E6B, 0x3956, 0x1F48, 0x1598, 0x1739, 0x204C, 0x2D65, 0x28C1, 0x1C9E, 0x0A1E, 0x1339, 0x2150
	DW	0x2ACC, 0x22C4, 0x1F3E, 0x2352, 0x2BDB, 0x2949, 0x24B5, 0x16B4, 0x182E, 0x19B9, 0x1C33, 0x1E40, 0x1E42, 0x26D4, 0x3175, 0x3FC3
	DW	0x1E4A, 0x0C91, 0x1A3B, 0x224E, 0x336A, 0x26C9, 0x1F0D, 0x071E, 0x10B4, 0x21DA, 0x2C4C, 0x25CB, 0x1EC1, 0x2658, 0x304F, 0x2857
	DW	0x1D31, 0x1FB7, 0x1A3D, 0x2241, 0x18AF, 0x1827, 0x16C0, 0x24CE, 0x2C68, 0x39FA, 0x3435, 0x24B1, 0x05A7, 0x1F3C, 0x27DF, 0x385E
	DW	0x25C5, 0x1086, 0x0A1B, 0x13B9, 0x2A61, 0x2C52, 0x2AC9, 0x265B, 0x32C5, 0x2158, 0x1AA9, 0x23C6, 0x1E47, 0x2BD2, 0x1DB1, 0x159C
	DW	0x09A6, 0x1BC0, 0x255A, 0x2B55, 0x2E6E, 0x39C5, 0x1B51, 0x1013, 0x1F41, 0x1E52, 0x32E4, 0x24BA, 0x158C, 0x0498, 0x14B9, 0x245F
	DW	0x2F57, 0x306A, 0x34D7, 0x18C3, 0x1B93, 0x17C8, 0x1FCE, 0x3065, 0x29B9, 0x199C, 0x0294, 0x12B3, 0x20D7, 0x3055, 0x2BE8, 0x36E5
	DW	0x26B7, 0x2226, 0x0DBD, 0x1FC3, 0x2C62, 0x31D3, 0x1F26, 0x098D, 0x0AA7, 0x1C49, 0x2F5E, 0x2DE1, 0x386F, 0x2F3E, 0x203A, 0x0CAA
	DW	0x20BD, 0x2762, 0x33DE, 0x26B6, 0x0E0E, 0x071C, 0x1640, 0x2AE0, 0x2EE1, 0x3372, 0x3451, 0x1C43, 0x139C, 0x1A3D, 0x20D7, 0x3065
	DW	0x2C41, 0x1598, 0x0795, 0x0F2E, 0x2354, 0x2D5C, 0x316A, 0x3867, 0x24B9, 0x1F9D, 0x0E35, 0x1CC4, 0x2CE6, 0x32D1, 0x1FA7, 0x088F
	DW	0x0B1F, 0x1ACA, 0x2BD9, 0x2FE3, 0x36EE, 0x313E, 0x203A, 0x0B24, 0x1C34, 0x255B, 0x31DF, 0x27BE, 0x1216, 0x0A95, 0x10B8, 0x23D5
	DW	0x2C5F, 0x3371, 0x3665, 0x20C1, 0x1A99, 0x12B6, 0x1B4C, 0x2E64, 0x2F4E, 0x1E28, 0x0C13, 0x0CA4, 0x1BC6, 0x2A57, 0x2EE5, 0x38F0
	DW	0x32C6, 0x23B6, 0x0C27, 0x1AB3, 0x245B, 0x315F, 0x26C1, 0x1819, 0x0C1D, 0x11B5, 0x2251, 0x29DD, 0x33EE, 0x38E9, 0x2648, 0x1E1A
	DW	0x13B5, 0x1843, 0x2ADE, 0x2ACC, 0x23B1, 0x0F22, 0x0EA4, 0x193E, 0x244D, 0x2CDF, 0x3570, 0x3553, 0x24C2, 0x1124, 0x1A2B, 0x1D4F
	DW	0x2B53, 0x27C8, 0x1BA7, 0x139F, 0x11AF, 0x1BC0, 0x24D4, 0x2CE6, 0x37EA, 0x2ECD, 0x242B, 0x1332, 0x1532, 0x234D, 0x26D0, 0x24BF
	DW	0x172D, 0x13A4, 0x16B2, 0x1D45, 0x2656, 0x30EC, 0x3661, 0x29CD, 0x1A2B, 0x182C, 0x16C0, 0x2348, 0x26CB, 0x2139, 0x1A30, 0x1530
	DW	0x19B8, 0x21C9, 0x28DA, 0x356C, 0x305D, 0x29BF, 0x1A34, 0x172D, 0x1DC1, 0x21CA, 0x2543, 0x2039, 0x1BB2, 0x1A35, 0x1CC1, 0x22CE
	DW	0x2BDE, 0x3466, 0x2C59, 0x26B9, 0x1E35, 0x17B8, 0x1E3E, 0x21C7, 0x2241, 0x1FBD, 0x1B39, 0x1CBA, 0x2044, 0x24D2, 0x2C5D, 0x30DD
	DW	0x2A53, 0x22BB, 0x1E35, 0x1B39, 0x1CBD, 0x1F41, 0x1FBD, 0x1FBA, 0x1CBC, 0x1CBD, 0x20C5, 0x2758, 0x2ED9, 0x2ED5, 0x2545, 0x1F36
	DW	0x1B37, 0x1CB7, 0x1FC0, 0x1EC0, 0x1EB8, 0x1E38, 0x1BBB, 0x1EBE, 0x21CA, 0x264E, 0x2A55, 0x2950, 0x2745, 0x203E, 0x1CB4, 0x1AB5
	DW	0x1A37, 0x1C38, 0x1CBE, 0x1EBF, 0x2247, 0x25D4, 0x2E5B, 0x2D55, 0x26C7, 0x1FBB, 0x1C37, 0x1DBF, 0x20C8, 0x24C7, 0x2443, 0x1EBA
	DW	0x1C34, 0x1A37, 0x1BBC, 0x2045, 0x244A, 0x274D, 0x27CD, 0x264C, 0x2548, 0x2443, 0x213F, 0x1E3C, 0x1D39, 0x1CBA, 0x1E3C, 0x2043
	DW	0x2249, 0x2752, 0x2C5A, 0x2CD7, 0x284E, 0x2341, 0x203C, 0x1E40, 0x2044, 0x22C4, 0x2240, 0x1FBC, 0x1C3B, 0x1C3A, 0x1E3C, 0x1FC0
	DW	0x2145, 0x2349, 0x25CC, 0x264D, 0x264A, 0x2445, 0x2140, 0x1E3A, 0x1BB6, 0x1B37, 0x1CBC, 0x1F41, 0x21C5, 0x23C8, 0x254C, 0x2850
	DW	0x2852, 0x26CB, 0x2543, 0x21C1, 0x1FC0, 0x2040, 0x1F3B, 0x1D38, 0x1AB7, 0x1BB7, 0x1E3B, 0x1E41, 0x21C6, 0x2751, 0x2957, 0x2B53
	DW	0x28CD, 0x23C5, 0x20BD, 0x1E39, 0x1CB9, 0x1D3C, 0x1F40, 0x2041, 0x20C1, 0x203F, 0x2042, 0x2143, 0x2348, 0x24CA, 0x264D, 0x274D
	DW	0x264A, 0x2343, 0x20BE, 0x1EBB, 0x1DBC, 0x1EBF, 0x2042, 0x21C4, 0x2347, 0x244A, 0x25CB, 0x264C, 0x264C, 0x25CA, 0x2445, 0x2141
	DW	0x1FBE, 0x1EBC, 0x1E3D, 0x1EBE, 0x2040, 0x2144, 0x22C6, 0x24CB, 0x26CE, 0x27CF, 0x274D, 0x2547, 0x22C1, 0x1FBD, 0x1E3B, 0x1D3A
	DW	0x1D3A, 0x1E3C, 0x1EBF, 0x20C1, 0x21C5, 0x244A, 0x26CE, 0x274E, 0x274B, 0x24C6, 0x21C1, 0x203E, 0x1EBD, 0x1E3C, 0x1E3D, 0x1EBE
	DW	0x1F3E, 0x1F3E, 0x1F3F, 0x1FC0, 0x2142, 0x2246, 0x2347, 0x23C7, 0x2346, 0x2345, 0x2243, 0x2141, 0x203F, 0x1FBF, 0x1FBF, 0x1FC0
	DW	0x20C1, 0x2143, 0x21C5, 0x2346, 0x23C7, 0x23C7, 0x23C6, 0x2345, 0x22C5, 0x2243, 0x21C2, 0x2142, 0x20C2, 0x2142, 0x21C4, 0x2244
	DW	0x22C6, 0x22C6, 0x2346, 0x2346, 0x2345, 0x2345, 0x2245, 0x2244, 0x2243, 0x21C2, 0x2142, 0x2143, 0x21C4, 0x21C3, 0x2244, 0x2244
	DW	0x2244, 0x2244, 0x2244, 0x21C3, 0x21C3, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x21C3, 0x21C4, 0x2244, 0x2244, 0x21C3, 0x21C3
	DW	0x21C3, 0x21C3, 0x2143, 0x21C2, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142, 0x2142
	DW	0x2142, 0x2143, 0x21C3, 0x21C4, 0x21C4, 0x2244, 0x2244, 0x2243, 0x21C3, 0x21C3, 0x21C2, 0x2142, 0x2142, 0x2143, 0x21C3, 0x21C4
	DW	0x2244, 0x22C5, 0x22C4, 0x2244, 0x2244, 0x2244, 0x2243, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x2244, 0x2244, 0x2244, 0x22C5, 0x2245
	DW	0x22C5, 0x22C5, 0x2244, 0x2244, 0x2244, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x2244, 0x2244, 0x2244, 0x2244, 0x2244, 0x21C4
	DW	0x21C3, 0x21C3, 0x21C3, 0x21C3, 0x21C2, 0x2142, 0x2143, 0x2142, 0x2040
SMP9	DW	0x2142, 0x21C3, 0x2245, 0x2346, 0x2346, 0x23C7, 0x23C5, 0x22C4, 0x2140, 0x1EBC, 0x1E3A, 0x1CB9, 0x1CBB, 0x1EBF, 0x21C5, 0x24CB
	DW	0x25CC, 0x264D, 0x264A, 0x23C5, 0x21C1, 0x1EBA, 0x1BB3, 0x182E, 0x1833, 0x1BBB, 0x2044, 0x2349, 0x25CE, 0x28D3, 0x29D3, 0x2950
	DW	0x274C, 0x24C6, 0x213C, 0x1B31, 0x15AA, 0x1630, 0x1A39, 0x2045, 0x24CD, 0x27D2, 0x2AD6, 0x2BD6, 0x2B54, 0x2950, 0x26CA, 0x2341
	DW	0x1D33, 0x1729, 0x14AE, 0x19B8, 0x2045, 0x24CE, 0x27D1, 0x2AD8, 0x2CD9, 0x2BD5, 0x2AD2, 0x27CB, 0x2443, 0x1E34, 0x16A7, 0x13AB
	DW	0x18B7, 0x1F45, 0x24CD, 0x274E, 0x28D4, 0x2B56, 0x2A52, 0x28D0, 0x2648, 0x223F, 0x1BB0, 0x14A3, 0x1127, 0x16B4, 0x1F43, 0x244D
	DW	0x2750, 0x28D3, 0x2AD6, 0x2AD3, 0x2850, 0x2647, 0x213C, 0x1AAE, 0x129F, 0x10A4, 0x1635, 0x1E44, 0x24CD, 0x2851, 0x29D5, 0x2BD7
	DW	0x2BD5, 0x29D1, 0x26C9, 0x223C, 0x19AD, 0x129F, 0x1025, 0x1738, 0x2047, 0x26D1, 0x2953, 0x2AD7, 0x2D5C, 0x2D58, 0x2B54, 0x284B
	DW	0x22BD, 0x1B30, 0x1423, 0x12AC, 0x1B38, 0x214C, 0x254C, 0x274B, 0x27D4, 0x2D61, 0x30D9, 0x2AD1, 0x2544, 0x1D2E, 0x14A9, 0x15B4
	DW	0x24E3, 0x35E0, 0x2539, 0x1AB5, 0x1BC2, 0x2B6B, 0x3864, 0x29C8, 0x223D, 0x1BB4, 0x192D, 0x14AA, 0x19CB, 0x3576, 0x33CD, 0x1BB0
	DW	0x17B1, 0x1F57, 0x38F6, 0x33D1, 0x223F, 0x1CB1, 0x17B0, 0x1528, 0x1636, 0x2365, 0x3BED, 0x28B6, 0x15AE, 0x18BE, 0x29EE, 0x3D6C
	DW	0x2AC8, 0x20B9, 0x18B1, 0x19AD, 0x1427, 0x1841, 0x29EE, 0x3AE2, 0x232F, 0x152F, 0x1D4E, 0x3276, 0x3A5F, 0x25C0, 0x1EBA, 0x1AB4
	DW	0x18AA, 0x13AC, 0x1CC6, 0x2E79, 0x3C5D, 0x1C24, 0x15B8, 0x2458, 0x367C, 0x38D6, 0x223E, 0x1FBD, 0x1AAE, 0x162F, 0x1935, 0x1DC7
	DW	0x31F9, 0x37CF, 0x192B, 0x1B41, 0x25DC, 0x38FD, 0x35CF, 0x203D, 0x21BE, 0x1829, 0x1735, 0x1BB3, 0x1DCA, 0x32FD, 0x35C8, 0x16AB
	DW	0x1DC4, 0x26DF, 0x3978, 0x31C7, 0x1FBF, 0x203E, 0x1AA7, 0x132F, 0x1D35, 0x1B42, 0x31F9, 0x36C3, 0x1328, 0x1D43, 0x255A, 0x3977
	DW	0x2FBF, 0x1C3F, 0x1FB7, 0x1624, 0x1531, 0x19AC, 0x1A44, 0x3176, 0x343D, 0x12A6, 0x1C43, 0x255D, 0x38F5, 0x2E3B, 0x1B3C, 0x1FBC
	DW	0x16A4, 0x152D, 0x1A31, 0x183D, 0x2C75, 0x3948, 0x14A4, 0x1A46, 0x2559, 0x38F7, 0x31C1, 0x19BE, 0x21BB, 0x17A6, 0x1635, 0x1AAC
	DW	0x1640, 0x2D70, 0x3A4F, 0x19AA, 0x19C1, 0x245C, 0x38F4, 0x3348, 0x1D3F, 0x1FBB, 0x1CAD, 0x132F, 0x1BB4, 0x1532, 0x2B74, 0x3FDB
	DW	0x18A8, 0x18C0, 0x24D4, 0x36F9, 0x364E, 0x1D3C, 0x223D, 0x19AC, 0x142C, 0x1A35, 0x17B6, 0x28E6, 0x3D61, 0x1DAB, 0x15B9, 0x2451
	DW	0x3675, 0x3653, 0x1CB9, 0x2240, 0x1BAB, 0x1129, 0x1A38, 0x172B, 0x2566, 0x3D67, 0x1DAA, 0x15B3, 0x204B, 0x33FA, 0x37D3, 0x1D36
	DW	0x24C3, 0x17A9, 0x11A9, 0x1A2D, 0x16B6, 0x25E0, 0x3AE6, 0x202A, 0x132F, 0x1FCA, 0x3478, 0x3855, 0x1D39, 0x21BF, 0x17AA, 0x142E
	DW	0x1830, 0x1A37, 0x26DF, 0x38E8, 0x20AF, 0x1630, 0x20CB, 0x337C, 0x3856, 0x1FB9, 0x2342, 0x172D, 0x16AD, 0x1B34, 0x17BF, 0x2BE6
	DW	0x3ADE, 0x1EB7, 0x18B1, 0x1F4F, 0x387D, 0x35D1, 0x21C3, 0x22B9, 0x19B2, 0x1730, 0x1BB3, 0x1946, 0x3064, 0x385A, 0x20BD, 0x19B0
	DW	0x20D4, 0x397B, 0x3351, 0x2445, 0x2231, 0x16B9, 0x1A2D, 0x19AF, 0x1DCE, 0x29DE, 0x38D5, 0x1F37, 0x17B5, 0x1FCE, 0x3774, 0x314F
	DW	0x2044, 0x22AD, 0x1539, 0x1A2E, 0x14AA, 0x1FC9, 0x29DF, 0x3755, 0x1E32, 0x1832, 0x1E4D, 0x35F4, 0x304B, 0x22C4, 0x1CAA, 0x15B5
	DW	0x18AF, 0x1AB2, 0x1BCA, 0x2A56, 0x31D3, 0x20BD, 0x19B2, 0x1FCE, 0x336C, 0x2ED0, 0x2544, 0x1FAF, 0x17B8, 0x17AC, 0x1A30, 0x1B48
	DW	0x2BDA, 0x3658, 0x21C2, 0x192D, 0x1F4B, 0x336E, 0x30DA, 0x2942, 0x2031, 0x16BE, 0x19AB, 0x1BB2, 0x1B49, 0x2955, 0x36E0, 0x2443
	DW	0x1CB3, 0x1CC2, 0x326F, 0x31E3, 0x2F48, 0x1BB5, 0x1B36, 0x182C, 0x1CBB, 0x19C1, 0x2B55, 0x30E0, 0x2648, 0x1E2E, 0x1DC3, 0x2AE8
	DW	0x32DF, 0x2C4A, 0x21B7, 0x1837, 0x182A, 0x18B4, 0x183A, 0x2955, 0x2EE6, 0x2845, 0x1EAE, 0x1A3C, 0x2662, 0x32DC, 0x2E51, 0x2035
	DW	0x19B2, 0x182B, 0x14B2, 0x1839, 0x2649, 0x2969, 0x2942, 0x23B8, 0x17B5, 0x2259, 0x2E5A, 0x3157, 0x203E, 0x1DAF, 0x152C, 0x182A
	DW	0x13B8, 0x24C6, 0x2A69, 0x2B49, 0x253C, 0x1732, 0x21D3, 0x2C5D, 0x335B, 0x26C5, 0x1FB6, 0x1729, 0x17AA, 0x12B0, 0x22CF, 0x276A
	DW	0x324E, 0x27C0, 0x1730, 0x1ECC, 0x2B5E, 0x3561, 0x28CF, 0x2337, 0x19B1, 0x16A3, 0x1432, 0x1DC4, 0x26E6, 0x3251, 0x2D4B, 0x1836
	DW	0x1F41, 0x275E, 0x325F, 0x2E59, 0x24C1, 0x1EB0, 0x16A7, 0x1228, 0x1A41, 0x265A, 0x31DE, 0x2ACE, 0x1E32, 0x1BBB, 0x2255, 0x2E5C
	DW	0x3057, 0x2748, 0x1E31, 0x1623, 0x0F9F, 0x153C, 0x1FD7, 0x32DA, 0x2E53, 0x1FB7, 0x19B6, 0x1F4A, 0x2C5C, 0x2EDE, 0x28CB, 0x22B7
	DW	0x172A, 0x109B, 0x15AF, 0x1C52, 0x2E5C, 0x305B, 0x25BE, 0x1EB6, 0x1D49, 0x2755, 0x2E5C, 0x2AD0, 0x243D, 0x192A, 0x1221, 0x102A
	DW	0x19C0, 0x2C56, 0x2E64, 0x27C9, 0x233A, 0x1E45, 0x2651, 0x2CDD, 0x2CD4, 0x2847, 0x1DB3, 0x1525, 0x1124, 0x1737, 0x2554, 0x2BE2
	DW	0x2D50, 0x26C6, 0x2146, 0x264F, 0x2B5B, 0x2D59, 0x2A4E, 0x22BB, 0x1B2B, 0x1425, 0x132F, 0x1C49, 0x28D8, 0x30D8, 0x29D3, 0x2548
	DW	0x264F, 0x28D6, 0x2D58, 0x2AD3, 0x2542, 0x1DB4, 0x1626, 0x12A6, 0x16B8, 0x21CC, 0x2A57, 0x29D1, 0x284A, 0x264F, 0x2854, 0x2B56
	DW	0x2B52, 0x2747, 0x20BC, 0x19AB, 0x13A3, 0x122A, 0x193B, 0x224B, 0x27CF, 0x2850, 0x274F, 0x29D4, 0x2A56, 0x2B54, 0x28CD, 0x2544
	DW	0x1F38, 0x18AB, 0x13A7, 0x152D, 0x19BB, 0x2045, 0x254C, 0x2753, 0x2BD9, 0x2DDC, 0x2E5B, 0x2C56, 0x29CE, 0x2545, 0x1F37, 0x182C
	DW	0x1528, 0x152D, 0x18B7, 0x1EC2, 0x23CD, 0x29D8, 0x2F62, 0x31E2, 0x305E, 0x2D56, 0x29CF, 0x2543, 0x1F39, 0x192E, 0x15AA, 0x152C
	DW	0x1835, 0x1DC2, 0x24CF, 0x2BDD, 0x30E4, 0x3263, 0x315F, 0x2DD8, 0x29CE, 0x24C5, 0x203A, 0x1A2F, 0x15AA, 0x152B, 0x16B3, 0x1C3D
	DW	0x224C, 0x29D8, 0x2EE0, 0x305F, 0x2F5B, 0x2C54, 0x284D, 0x24C3, 0x1F3A, 0x1A2F, 0x15A9, 0x13A8, 0x152E, 0x19BA, 0x20C8, 0x2754
	DW	0x2C5C, 0x2EDD, 0x2E59, 0x2B54, 0x284C, 0x24C5, 0x203B, 0x1BB2, 0x16A9, 0x1427, 0x14AD, 0x18B6, 0x1EC2, 0x244E, 0x29D7, 0x2D5C
	DW	0x2E5B, 0x2CD7, 0x2A51, 0x26C9, 0x22C1, 0x1E37, 0x192F, 0x162C, 0x16AE, 0x18B5, 0x1CBE, 0x21C8, 0x26D2, 0x2B5A, 0x2E5D, 0x2EDC
	DW	0x2CD7, 0x29CF, 0x25C7, 0x21BF, 0x1DB8, 0x1B34, 0x19B3, 0x19B4, 0x1BB9, 0x1EC1, 0x22CA, 0x27D4, 0x2C5A, 0x2E5C, 0x2E59, 0x2BD2
	DW	0x274B, 0x2343, 0x203C, 0x1CB7, 0x1A33, 0x19B3, 0x1A35, 0x1C3A, 0x1F42, 0x23CB, 0x27D3, 0x2B57, 0x2C58, 0x2B55, 0x294F, 0x2649
	DW	0x2343, 0x203D, 0x1DB8, 0x1B35, 0x1A34, 0x1AB6, 0x1C3B, 0x1F41, 0x2247, 0x24CB, 0x274F, 0x2850, 0x28D0, 0x274C, 0x2547, 0x2242
	DW	0x1FBD, 0x1D38, 0x1BB6, 0x1B37, 0x1C39, 0x1D3C, 0x1F40, 0x2144, 0x2348, 0x25CC, 0x274F, 0x27CF, 0x274D, 0x2548, 0x22C3, 0x20BF
	DW	0x1EBC, 0x1DBA, 0x1D3A, 0x1D3B, 0x1DBC, 0x1F40, 0x2144, 0x2348, 0x254D, 0x274F, 0x27CF, 0x274D, 0x264A, 0x2446, 0x22C3, 0x2140
	DW	0x1FBE, 0x1F3D, 0x1EBD, 0x1F3F, 0x2042, 0x21C5, 0x23C9, 0x254B, 0x264D, 0x26CE, 0x274D, 0x26CC, 0x2548, 0x2345, 0x2141, 0x1FBE
	DW	0x1EBD, 0x1EBD, 0x1F3F, 0x2041, 0x2143, 0x21C4, 0x22C6, 0x23C8, 0x2449, 0x24C9, 0x2447, 0x23C6, 0x2243, 0x2141, 0x203F, 0x1FBE
	DW	0x1F3F, 0x1F3F, 0x1FBF, 0x2040, 0x20C2, 0x21C4, 0x22C6, 0x2347, 0x23C7, 0x23C6, 0x2345, 0x2243, 0x2142, 0x20C1, 0x2040
SMPP	DW	0x1FBF, 0x1FC0, 0x2040, 0x20C1, 0x20C1, 0x203F, 0x1FBF, 0x1FBF, 0x2040, 0x1FBF, 0x1F3D, 0x1DB9, 0x1C38, 0x1C39, 0x1DBB, 0x1DBA
	DW	0x1DBB, 0x1E3C, 0x1EBC, 0x1DBA, 0x1D3B, 0x1E3D, 0x1F3E, 0x1F3E, 0x1EBC, 0x1E3D, 0x1EBD, 0x1E39, 0x1C38, 0x1CBC, 0x1EBD, 0x1E3B
	DW	0x1D3B, 0x1DBB, 0x1CB8, 0x1CBA, 0x1E3D, 0x1EBC, 0x1DBC, 0x1F3F, 0x203E, 0x1E3C, 0x1E3D, 0x1FBD, 0x1F3D, 0x1EBE, 0x1FBF, 0x1FBF
	DW	0x2041, 0x20C1, 0x203F, 0x1FBE, 0x1EBC, 0x1DBB, 0x1E3C, 0x1E3D, 0x1EBF, 0x1FC1, 0x2142, 0x2242, 0x21C3, 0x2143, 0x2244, 0x2242
	DW	0x20BF, 0x2041, 0x20BF, 0x1EBC, 0x1E3D, 0x1F3D, 0x1EBC, 0x1E3D, 0x1FC1, 0x21C4, 0x22C6, 0x244A, 0x24C8, 0x2448, 0x24CA, 0x24C9
	DW	0x23C6, 0x22C4, 0x20BE, 0x1EBD, 0x1EBE, 0x1E3A, 0x1CB9, 0x1E41, 0x2248, 0x2549, 0x2447, 0x244B, 0x274F, 0x27CD, 0x2547, 0x22C5
	DW	0x2242, 0x1F3B, 0x1CB8, 0x1C37, 0x1A30, 0x1730, 0x1BC1, 0x26D1, 0x284C, 0x23C7, 0x254C, 0x2649, 0x23C8, 0x254D, 0x2647, 0x20BB
	DW	0x1C38, 0x1D3A, 0x1C33, 0x172B, 0x17B8, 0x21CF, 0x2BD8, 0x2ACE, 0x22C0, 0x1EBE, 0x224B, 0x2853, 0x284A, 0x213A, 0x1BB9, 0x1EBF
	DW	0x1E33, 0x16AB, 0x18BB, 0x224D, 0x2A5A, 0x2EDA, 0x28C3, 0x1C35, 0x1F4C, 0x2DDF, 0x2D4D, 0x2139, 0x1BB8, 0x1DBD, 0x1DB2, 0x1629
	DW	0x183B, 0x22CF, 0x2AD9, 0x2DD5, 0x25BC, 0x1933, 0x1FD0, 0x2F61, 0x2D4C, 0x1F35, 0x19B7, 0x1DBD, 0x1CB0, 0x13A8, 0x183D, 0x25D3
	DW	0x2EE2, 0x2BCE, 0x1EB1, 0x1939, 0x24DB, 0x30E2, 0x2C47, 0x1E32, 0x1939, 0x1E3D, 0x1C29, 0x11AB, 0x1ACB, 0x2D5F, 0x315A, 0x27C5
	DW	0x1BAF, 0x193C, 0x29E4, 0x3462, 0x273A, 0x17AD, 0x1C40, 0x1FB8, 0x149F, 0x1538, 0x265E, 0x3162, 0x2E4F, 0x2234, 0x152E, 0x1ED5
	DW	0x34EC, 0x314D, 0x1BAD, 0x1738, 0x2140, 0x1AA4, 0x0EAA, 0x1F56, 0x31E5, 0x2F55, 0x243D, 0x17A8, 0x17C1, 0x2DEC, 0x365C, 0x222E
	DW	0x132C, 0x1CC1, 0x1E2D, 0x0E1E, 0x18C9, 0x3068, 0x325C, 0x2741, 0x1A28, 0x1436, 0x26E7, 0x3868, 0x29BA, 0x15AB, 0x1A40, 0x1FB5
	DW	0x129D, 0x15C0, 0x2D6B, 0x3767, 0x2D47, 0x1BA7, 0x11AF, 0x23E2, 0x39EF, 0x2EC5, 0x182B, 0x1839, 0x1EB9, 0x159F, 0x143B, 0x2BEE
	DW	0x3BF1, 0x3048, 0x1A25, 0x112F, 0x2361, 0x39F2, 0x324C, 0x1AAC, 0x1738, 0x203E, 0x18A0, 0x1339, 0x29EF, 0x3C74, 0x31CB, 0x1BA7
	DW	0x102B, 0x205C, 0x38F4, 0x344F, 0x1AAA, 0x15B5, 0x1EBC, 0x171E, 0x10B6, 0x2A6F, 0x3D72, 0x304A, 0x1AA6, 0x1027, 0x1E5A, 0x3876
	DW	0x33CE, 0x19A8, 0x16B4, 0x1DB6, 0x149A, 0x11B8, 0x2A6E, 0x3C72, 0x314B, 0x1922, 0x0E26, 0x1F5B, 0x3874, 0x33D0, 0x1BA9, 0x13AE
	DW	0x1B38, 0x1620, 0x13B9, 0x2AEE, 0x3DF4, 0x30C7, 0x1925, 0x112A, 0x205B, 0x3876, 0x3553, 0x1DAC, 0x15AF, 0x1BB8, 0x1723, 0x153C
	DW	0x2A6C, 0x3DF5, 0x32CD, 0x1B26, 0x112B, 0x20DB, 0x3876, 0x3656, 0x1F2D, 0x152F, 0x1A36, 0x169F, 0x1641, 0x2BEE, 0x3CF2, 0x324C
	DW	0x19A4, 0x1029, 0x20DC, 0x37F3, 0x34D4, 0x1FAE, 0x152A, 0x1630, 0x149D, 0x14BC, 0x2C74, 0x3FF3, 0x2F43, 0x1722, 0x0F26, 0x205B
	DW	0x3875, 0x3451, 0x1E2D, 0x1427, 0x15AF, 0x141C, 0x16C0, 0x2BF1, 0x3DED, 0x2F45, 0x1823, 0x0FA7, 0x215C, 0x3671, 0x33D3, 0x1FAE
	DW	0x12A5, 0x142C, 0x131A, 0x153F, 0x2BED, 0x3BEB, 0x2E46, 0x1820, 0x0E24, 0x2059, 0x356E, 0x3355, 0x2130, 0x12A4, 0x152D, 0x1217
	DW	0x1441, 0x2C6A, 0x3AEE, 0x304D, 0x19A2, 0x0F26, 0x1ED6, 0x32ED, 0x35DA, 0x2234, 0x13A7, 0x14A8, 0x101A, 0x1544, 0x28E6, 0x3C71
	DW	0x314E, 0x1AA6, 0x1226, 0x1C54, 0x326E, 0x3659, 0x23BC, 0x1629, 0x152A, 0x119A, 0x153E, 0x2864, 0x3AF1, 0x3353, 0x1F2C, 0x12A5
	DW	0x1BD0, 0x306A, 0x36E0, 0x273D, 0x17AB, 0x1527, 0x109A, 0x143B, 0x2460, 0x3B71, 0x3256, 0x21B0, 0x1321, 0x194D, 0x2D63, 0x3562
	DW	0x2840, 0x192E, 0x1626, 0x0F99, 0x1335, 0x1ED1, 0x37F1, 0x3158, 0x25B9, 0x15A0, 0x16C7, 0x29D9, 0x33E6, 0x2AC3, 0x1BB0, 0x1727
	DW	0x0E18, 0x11AE, 0x1BD0, 0x35EF, 0x325D, 0x293E, 0x15A3, 0x1740, 0x2558, 0x33E6, 0x2A47, 0x1F34, 0x16A9, 0x109A, 0x0EA5, 0x194F
	DW	0x31E8, 0x32E6, 0x2BC1, 0x18AB, 0x173B, 0x2255, 0x32E3, 0x29CC, 0x23B7, 0x17AE, 0x141B, 0x0F26, 0x17C8, 0x2EE0, 0x32EA, 0x2D47
	DW	0x1EB4, 0x1839, 0x2353, 0x2F5F, 0x2C52, 0x233A, 0x1BB4, 0x149C, 0x1028, 0x14C0, 0x2BDF, 0x2FE6, 0x2FCD, 0x1F38, 0x1AB8, 0x20CE
	DW	0x2DDD, 0x2AD1, 0x25BE, 0x1AB7, 0x17A0, 0x0F26, 0x1339, 0x2657, 0x2E63, 0x2F52, 0x22BC, 0x1C39, 0x204B, 0x2AD9, 0x2AD2, 0x263F
	DW	0x1C3C, 0x1821, 0x112A, 0x0FB5, 0x2453, 0x2A61, 0x2F56, 0x2342, 0x1F3A, 0x1F4C, 0x29D4, 0x2AD2, 0x25C2, 0x1E3B, 0x1AA5, 0x11AB
	DW	0x102E, 0x23CB, 0x26E0, 0x2F52, 0x2648, 0x203D, 0x204D, 0x2851, 0x2B55, 0x24C5, 0x21B9, 0x1B2F, 0x12A7, 0x12B0, 0x1E47, 0x27D9
	DW	0x2D56, 0x284A, 0x2240, 0x21CB, 0x26D2, 0x2BD0, 0x25CA, 0x203C, 0x1DAF, 0x142C, 0x11AC, 0x1DC0, 0x24D5, 0x2AD4, 0x28CB, 0x23C2
	DW	0x224C, 0x264F, 0x2ACF, 0x25CA, 0x2140, 0x1EB2, 0x16AC, 0x11AB, 0x1B39, 0x21CE, 0x2852, 0x284E, 0x24C4, 0x23CC, 0x2550, 0x29CE
	DW	0x264A, 0x21C0, 0x1F39, 0x172E, 0x14A7, 0x1937, 0x1F48, 0x2651, 0x27CD, 0x2647, 0x23CC, 0x26CF, 0x2A50, 0x274B, 0x23C3, 0x213B
	DW	0x1B2F, 0x1727, 0x18B4, 0x1D42, 0x254C, 0x274D, 0x26CA, 0x24CD, 0x27D0, 0x29D3, 0x284D, 0x2646, 0x21C1, 0x1DB4, 0x18AD, 0x1733
	DW	0x1BBB, 0x22C6, 0x26CC, 0x26CC, 0x264E, 0x2853, 0x29D5, 0x2951, 0x26CA, 0x23C3, 0x20BB, 0x1A34, 0x16B2, 0x1A37, 0x1F42, 0x234A
	DW	0x254B, 0x264B, 0x2851, 0x2A54, 0x29D2, 0x27CC, 0x2547, 0x2240, 0x1DB5, 0x1A30, 0x19B4, 0x1B3D, 0x1F44, 0x22C7, 0x24CA, 0x26D0
	DW	0x2953, 0x2AD2, 0x28CE, 0x2648, 0x2343, 0x1FBA, 0x1C34, 0x18B3, 0x1A36, 0x1D3C, 0x2041, 0x2247, 0x244D, 0x27D2, 0x29D3, 0x2950
	DW	0x274C, 0x24C6, 0x22BF, 0x1E38, 0x1B33, 0x19B5, 0x1AB8, 0x1D3C, 0x1F41, 0x2247, 0x25CE, 0x28D2, 0x29D2, 0x284F, 0x264B, 0x2446
	DW	0x21C0, 0x1E39, 0x1BB5, 0x1AB5, 0x1B38, 0x1CBC, 0x1FC1, 0x22C9, 0x264F, 0x2851, 0x28D0, 0x27CE, 0x26CB, 0x24C7, 0x2240, 0x1EBB
	DW	0x1C36, 0x1B36, 0x1B37, 0x1CBB, 0x1F41, 0x2248, 0x25CD, 0x27D0, 0x28D1, 0x2850, 0x27CD, 0x2547, 0x2241, 0x1F3B, 0x1C37, 0x1AB5
	DW	0x1AB6, 0x1C3B, 0x1EC0, 0x21C7, 0x254C, 0x27D0, 0x2850, 0x284F, 0x274C, 0x24C6, 0x2240, 0x1EBB, 0x1C37, 0x1B36, 0x1B37, 0x1C3A
	DW	0x1EBF, 0x2145, 0x244A, 0x264E, 0x27CF, 0x274E, 0x264A, 0x2446, 0x21C0, 0x1F3B, 0x1CB8, 0x1BB7, 0x1BB8, 0x1CBB, 0x1EBF, 0x20C4
	DW	0x2349, 0x25CC, 0x26CD, 0x26CC, 0x25CA, 0x2446, 0x2241, 0x1FBD, 0x1E3A, 0x1D39, 0x1CBA, 0x1DBC, 0x1F3F, 0x2144, 0x23C9, 0x25CC
	DW	0x26CD, 0x26CC, 0x25CA, 0x2446, 0x22C3, 0x20BF, 0x1F3D, 0x1E3B, 0x1DBC, 0x1E3E, 0x1FC1, 0x21C5, 0x23C9, 0x254C, 0x264D, 0x264C
	DW	0x25CA, 0x2447, 0x22C3, 0x2140, 0x1FBE, 0x1EBD, 0x1EBD, 0x1F3F, 0x2041, 0x21C5, 0x2348, 0x24CA, 0x254A, 0x254A, 0x24C8, 0x23C6
	DW	0x2243, 0x2140, 0x1FBF, 0x1F3E, 0x1F3E, 0x1FBF, 0x2042, 0x21C4, 0x22C6, 0x23C8, 0x2448, 0x2448, 0x23C7, 0x2345, 0x2243, 0x2141
	DW	0x2040, 0x1FBF, 0x1FBF, 0x2040, 0x20C2, 0x21C4, 0x2245, 0x2346, 0x2347, 0x23C6, 0x2346, 0x22C5, 0x2243, 0x2142, 0x20C1, 0x20C1
	DW	0x20C1, 0x20C2, 0x2143, 0x21C4, 0x2245, 0x22C5, 0x2346, 0x2346, 0x22C5, 0x22C4, 0x2244, 0x21C3
SMPEND

	END
